# Create histogram
# by Aaron Albin
# Script began: 3/28/2012

###########################
# WHEN TO USE THIS SCRIPT #
########################### 

# Use this script when you have a single set of numbers and you want to see how those numbers are distributed.
# This is known as a 'histogram'.
# Note that this looks similar to, but is in fact different from, barplots.

###############
# SELECT DATA #
###############

# Run this to have R tell you the names for each of the columns that it ended up with:
#=====[1]=====
colnames(Dataframe)
#=============

# Now, pick out which of these columns has the number data whose distribution you want to see.
# Type the name of that column inside the double-quotes below.
#=====[2]=====
NumberData = Dataframe[,"NumberColumn"]
# NumberData = Dataframe[,"F4"]
#=============

###############################
# SPECIFY PARAMETERS FOR PLOT #
###############################

# Set the name for the main title (centered along the top of the plot) here.
#=====[3]=====
MainTitle = "Histogram"
#=============

# Set the number of bars you would like to appear in the histogram, provided as a single number, e.g. NumberOfBars=10. (Note that you don't need quotes.)
# R will do its best to create exactly that number of bars, but depending on your data, the actual number of bars you end up with  might be slightly different.
# If you would like R to compute the number of bars automatically for you, just say NumberOfBars = "Sturges" instead (telling R to use Sturges' formula, which uses information on the range of the data).
# Depending on your choice in this step, R will compute the limits/range of the x-axis for you.
#=====[4]=====
NumberOfBars = "Sturges"
#=============

# Below the double-quotes below, you can insert a few words you would like to use as the 'x-axis label', i.e. the words printed below of the numbers along the horizontal axis in the histogram you will ultimately produce.
# Typically, this would be the name of the thing being measured that your number-data represent.
#=====[5]=====
xAxisLabel = ""
#=============

# In the histogram you are creating, you can either see how your data are distributed in terms of raw frequency counts (how many times individual data points fell within certain ranges of values) or in terms of 'probability density' (roughly, what percentage of the time did the data points fall within those ranges).
# Set PlotAsFrequencyCounts to TRUE if you want the former (raw frequency counts)
# Set PlotAsFrequencyCounts to FALSE if you want the latter (probability 'densities')
# The y-axis label (printed to the left of the numbers along the vertical axis in the histogram you will ultimately produce) will be set accordingly (as either 'Frequency' or 'Density').
#=====[6]=====
PlotAsFrequencyCounts = FALSE
#=============

# Generally, it is a good idea to let R determine the limits (i.e. range) of the y-axis for you, too. However, if you would like to adjust them, you can do that here.
# Just say 'yAxisLimits = c( ___, ___ )', where the two '___'s indicate the lower and upper bound (respectively) of the range for the y-axis. (Be sure to put the lower bound first or else your bars will be upside-down!)
# Note that your setting in the last step ('PlotAsFrequencyCounts') will have an impact here.
#=====[7]=====
yAxisLimits = NULL
#=============

# If you set the following to TRUE, R will insert labels above your bars to indicate what numerical value each bar represents.
#=====[8]=====
LabelsAboveBars = FALSE
#=============

# If you would like your bars to each be filled with a color, indicate here the name of the color you would like to use.
# Be sure to surround the name of the color with double-quotes, e.g. BarFillColor = "blue".
# If you leave this set to NULL, the bars in your histogram will be unfilled.
# Type 'colors()' (without the single-quotes) at the R console and hit ENTER to see the list of all the color names R accepts.
#=====[9]=====
BarFillColor = NULL
#=============

# Rather than have R *fill* your bars with this color, you can also have R draw 'shading lines' (e.g. diagonal ones) inside them for a visual effect.
# To do so, instead of NULL below, you can set 'DensityOfShadingLines' equal to a whole number (e.g. 10), indicating how many lines per inch you would like to have.
# Then, set 'AngleOfShadingLines' to the number of degrees (counter-clockwise) for the slope you would like those shading lines to have. 
# If you set 'BarFillColor' in the last step, this color will be applied to those shading lines.
# Even if you don't want shading lines, you need to run these two lines of code regardless (making sure DensityOfShadingLines is set to NULL).
#=====[10]=====
DensityOfShadingLines = NULL
AngleOfShadingLines = 45
#==============

# If you would like to set the border around your bars to be in some color other than black, indicate here the name of the color you would like to use.
# Be sure to surround the name of the color with double-quotes, e.g. BarBorderColor = "red".
# Leaving this set to NULL keeps the border color as black.
# Again, type 'colors()' (without the single-quotes) at the R console and hit ENTER to see the list of all the color names R accepts.
#=====[11]=====
BarBorderColor = NULL
#==============

###############
# CREATE PLOT #
###############

# Finally, run the following line of code to apply all the parameters you just set and create your histogram.
#=====[12]=====
hist(x=NumberData, main=MainTitle, breaks=NumberOfBars, xlab=xAxisLabel, freq=PlotAsFrequencyCounts, ylim=yAxisLimits, labels=LabelsAboveBars, col=BarFillColor, density=DensityOfShadingLines, angle=AngleOfShadingLines, border=BarBorderColor, plot=TRUE, axes=TRUE, include.lowest=TRUE, right=TRUE)
#=============


### For advanced users:

# [A]

# In 'NumberOfBars' in step [5], in addition to 'Sturges', you also can choose from either of the following other algorithms to compute the number of bars.
# Therefore, you may want to try running one of the following, then proceed with steps [6] through [12].
NumberOfBars = "Scott" # Scott's choice for a normal distribution based on the estimate of the standard error.
NumberOfBars = "Freedman-Diaconis" # the Freedman-Diaconis choice based on the inter-quartile range. 

# [B]

# Run the following code to learn have R print to the console various pieces of diagnostic information about your histogram:

hist(x=NumberData, breaks=NumberOfBars, plot=FALSE)$counts
# The (whole) number of counted data points/observations going into each of the bars

hist(x=NumberData, breaks=NumberOfBars, plot=FALSE)$density
# The probability 'density' value for each of the bars

hist(x=NumberData, breaks=NumberOfBars, plot=FALSE)$breaks
# The boundaries between each pair of bars in the histogram

hist(x=NumberData, breaks=NumberOfBars, plot=FALSE)$mids
# The midpoints of each of the bars in the histogram
