# Create X-Y scatterplot: All coded the same
# by Aaron Albin
# Script began: 4/11/2012

###########################
# WHEN TO USE THIS SCRIPT #
########################### 

# Use this script when both of the following is true:
# * Inside your dataframe, you have two sets of numeric data stored as two separate columns, and the individual data points inside the two are related to each other (or 'paired'). This is applicable, for instance, whenever a single event/phenomenon/subject simultaneously yields two data points.
# * You wish to plot these numbers onto a 'scatterplot', where the horizontal axis corresponds to one of your columns of numbers and the vertical axis corresponds to the other. Each individual pair of numbers, then, is represented as a point in this two-dimensional space.
# * You want all points in the plot to be plotted in the same way, i.e. with the same color, symbol, size, etc.

# Note: In this script, you will not have the option of adding a legend.

###############
# SELECT DATA #
###############

# Run this to have R tell you the names for each of the columns that it ended up with after importing the dataframe:
#=====[1]=====
colnames(Dataframe)
#=============

# Now, pick out which two of these columns have your number data.
# Type the names of those columns between the double-quotes below (leaving the other code untouched).
# Which you choose as 'NumberDataX' and which you choose as 'NumberDataY' is important here.
# The horizontal axis will correspond to the values you set as 'NumberDataX', and the vertical axis will correspond to the values you set as 'NumberDataY'.
# Throughout this script, it will be useful to keep this naming system in mind - x=horizontal and y=vertical.
#=====[2]=====
NumberDataX = Dataframe[,"NumberColumn1"]
NumberDataY = Dataframe[,"NumberColumn2"]
#NumberDataX = Dataframe[,"OPEN_DUR"]; NumberDataY = Dataframe[,"GLOTT_DUR"]
#=============

###############################
# SPECIFY PARAMETERS FOR PLOT #
###############################

# Set the name for the main title (centered along the top of the plot) here.
#=====[3]=====
MainTitle = "Scatterplot"
#=============

# Generally, it is a good idea to let R determine the limits (i.e. range) of the x (horizontal) axis and y (vertical) axis for you. 
# Leaving the values below as NULL will have this effect.
# However, if you would like to adjust them, you can do that here.
# Just say xAxisLimits or yAxisLimits equal to 'c( ___, ___ )', where the two '___'s indicate the lower and upper bound (respectively) of the range for the relevant axis.
# If you want the axis to be backwards/flip-flopped, then but the upper bound first, followed by the lower bound, e.g. rather than c(5,100) say c(100,5).
#=====[4]=====
xAxisLimits = NULL
yAxisLimits = NULL
#=============

# Below the double-quotes below, you can insert a few words you would like to use as the 'axis labels' for the x and y axes.
# In the quotes after 'xAxisLabel', type the words(s) you want to see displayed beneath the x (horizontal) axis.
# In the quotes after 'yAxisLabel', type the word(s) you want to see displayed to the left of the y (vertical) axis.
# If you don't want to include an axis label at all for either of these, just leave the double-quotes empty, i.e. "", for that one.
#=====[5]=====
xAxisLabel = ""
yAxisLabel = ""
#=============

# In some applications, the interesting patterns in your numbers are happening at small numbers (e.g. under 10), but you have a few outliers (e.g. over 100) that are forcing R to zoom out far enough to encompass all the data, so far that you can't see the interesting patterns in your data in the small-number range.
# To overcome this problem, you can have R plot one or both of the axes 'logarithmically'.
# What this means is that, visually, smaller numbers will be 'given more space', whereas the higher numbers will be 'scrunched together' more.
# Below, indicate which axes
# PlotWhichAxesLogarithmically = "" means you don't want either axis to be plotted logarithmically
# PlotWhichAxesLogarithmically = "x" means you want the horizontal axis to be plotted logarithmically
# PlotWhichAxesLogarithmically = "y" means you want the vertical axis to be plotted logarithmically
# PlotWhichAxesLogarithmically = "xy" means you want *both* axes to be plotted logarithmically
# Note: If you choose to plot an axis logarithmically, any zeroes and any negative numbers will be omitted from the plot. (R will give you a warning telling you how many total points this was.) This is necessary because of how the underlying logarithmic transformation itself works.
#=====[6]=====
PlotWhichAxesLogarithmically = ""
#=============

# Choose here the symbol that you want to use for all the points that get plotted in the scatter plot. Each symbol is represented by a special 'code number':
#  1 = unfilled circle
#  0 = unfilled square
#  2 = unfilled triangle
#  5 = unfilled diamond
# 16 =   filled circle
# 15 =   filled square
# 17 =   filled triangle
# 18 =   filled diamond
#  3 = a plus sign (i.e. '+')
#  4 = an 'x' symbol
#  8 = a star composed of '+' and 'x' superimposed
# You should *not* surround any numbers like these with quotes.
# Indicate which one you like by typing the code number below after the equals sign (without quotes).
#=====[7]=====
PointSymbol = 1
#=============

# Here, you can choose the color that you would like R to use when drawing all of your points on the scatterplot.
# Type 'colors()' (without the single-quotes) at the R console and hit ENTER to see the list of all the color names R accepts.
# Be sure to surround the name of the color with double-quotes, e.g. "black".
#=====[8]=====
PointColor = "black"
#=============

# If you would like your points to be bigger or smaller, the following lets you adjust their size.
# '1' represents 100% of the default size, so if you want to make the points larger you could type, for example, 1.5 (i.e. 150%). Similarly, if you want to make them smaller you could type 0.5 (i.e. 50%).
#=====[9]=====
PointSizeModifier = 1
#=============

###############################
# SPECIFY PARAMETERS FOR GRID #
###############################

# This section lets you add a 'grid' to the plot, running across the main plotting region to help you keep track of where things align with the axes.
# R will draw lines wherever the 'tick marks' are on both axes. If you wish to adjust these, change 'xAxisLimits' and 'yAxisLimits' above.

# Choose the type of line you would like to use for your gridlines. You have the following six choices:
#  "solid"    = -----------------------------------------------
#  "dashed"   = ----    ----    ----    ----    ----    ----   
#  "dotted"   = -   -   -   -   -   -   -   -   -   -   -   -  
#  "dotdash"  = -   ----   -   ----   -   ----   -   ----   -  
#  "longdash" = -------   -------   -------   -------   -------
#  "twodash"  = --  ------  --  ------  --  ------  --  ------ 
# If you do not want gridlines on your plot, choose "blank" instead.
#=====[10]=====
GridlineType = "blank"
#=============

# Choose the color for your grid lines. See step 8 for help on choosing the color.
#=====[11]=====
GridlineColor = "lightgrey"
#=============

# If you would like your gridlines to be thicker, the following lets you increase its width.
# '1' represents 100% of the default thickness, so for example, you could type 2 to make it 200% that thickness.
#=====[12]=====
GridlineWidthModifier = 1
#=============

###############
# CREATE PLOT #
###############

# Finally, run the following line of code to apply all the parameters you just set and create your scatterplot and grid.
#=====[13]=====
plot.default(x=NumberDataX, y=NumberDataY, main=MainTitle, xlim=xAxisLimits, ylim=yAxisLimits, xlab=xAxisLabel, ylab=yAxisLabel, log=PlotWhichAxesLogarithmically, pch=PointSymbol, col=PointColor, cex=PointSizeModifier, type="p", ann=TRUE, axes=TRUE, frame.plot=TRUE, panel.first=grid(lty=GridlineType, col=GridlineColor, lwd=GridlineWidthModifier), panel.last=NULL, asp=NA)
#=============

#######################
# FIT REGRESSION LINE #
#######################

# This section is for when you want to add a 'best-fit' regression line to the plot.

# Choose the type of line you would like to use for your regression line. See step 10 above for help.
#=====[14]=====
RegressionLineType = "solid"
#=============

# Choose the color for your regression line. See step 8 for help on choosing the color.
#=====[15]=====
RegressionLineColor = "red"
#=============

# You may adjust the thickness of your regression line here. See step 12 for help.
#=====[16]=====
RegressionLineWidthModifier = 1
#=============

# The following code actually adds the regression line to the plot.
#=====[17]=====
abline(reg=lm(formula=NumberDataY~NumberDataX),lty=RegressionLineType,col=RegressionLineColor,lwd=RegressionLineWidthModifier)
#=============
