


_______________
ANOVA_One-way.r



colnames(Dataframe)
Name_NumberColumn = 'NumberColumn1'
Name_LabelColumn = 'LabelColumn1'
NumberData = Dataframe[,Name_NumberColumn]
Conditions = as.factor(Dataframe[,Name_LabelColumn])
PercentageForConfidenceInterval = 0.95
FittedModel = aov(NumberData ~ Conditions, qr=TRUE, contrasts=NULL) 
ResultsSummary = summary.aov(object=FittedModel,intercept=FALSE,keep.zero.df=TRUE) 
ConditionMeans = model.tables(x=FittedModel,type='means',se=FALSE) 
TukeyHSD = TukeyHSD(x=FittedModel,ordered=FALSE, conf.level=PercentageForConfidenceInterval) 
cat('\n\nDESCRIPTIVE STATISTICS\n~~~~~~~~~~~~~~~~~~~~~~\nOverall mean across the entire dataset = ',ConditionMeans$tables$'Grand mean','\n\nMean for each condition:\n',sep='')
nConditions = length(ConditionMeans$tables$Conditions)
for(EachCondition in 1:nConditions){ExtractedN = ConditionMeans$n$Conditions[EachCondition]
if(!is.na(ExtractedN)){CurrentN=ExtractedN}else{CurrentN=ConditionMeans$n$Conditions[1]}
cat(' * Condition '',names(ConditionMeans$tables$Conditions)[EachCondition],'': ',ConditionMeans$tables$Conditions[EachCondition],' (',CurrentN,' observations)\n',sep='')}
cat('\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nA one-way ANOVA was run on '',Name_NumberColumn,'' as grouped by '', Name_LabelColumn, ''.\n\n\nRESULTS\n~~~~~~~\nOverall across all conditions of '', Name_LabelColumn, '':\n   F(',ResultsSummary[[1]]['Conditions','Df'],',',ResultsSummary[[1]]['Residuals','Df'],') = ',ResultsSummary[[1]]['Conditions','F value'],', p = ',ResultsSummary[[1]]['Conditions','Pr(>F)'],'\n\n',sep='')
nComparisons = nrow(TukeyHSD$Conditions)
for(EachComparison in 1:nComparisons){cat('Comparison '',rownames(TukeyHSD$Conditions)[EachComparison],'': Mean = ',TukeyHSD$Conditions[EachComparison,'diff'],', ', 100*PercentageForConfidenceInterval, '% confidence interval [',TukeyHSD$Conditions[EachComparison,'lwr'],', ',TukeyHSD$Conditions[EachComparison,'upr'],'], p = ',TukeyHSD$Conditions[EachComparison,'p adj'],'\n',sep='')}
cat('\n')
show(ConditionMeans)
show(ResultsSummary)
show(TukeyHSD)



________________________________
ANOVA_One-way_RepeatedMeasures.r



colnames(Dataframe)
Name_NumberColumn  = 'NumberColumnName'
Name_LabelColumn   = 'LabelColumnName'
Name_SubjectColumn = 'SubjectColumnName'
NumberData = Dataframe[,Name_NumberColumn]
Conditions = as.factor(Dataframe[,Name_LabelColumn  ])
Subjects   = as.factor(Dataframe[,Name_SubjectColumn])
PercentageForConfidenceInterval = 0.95
FittedModel_FullDataset=aov(NumberData ~ Conditions + Error(Subjects/Conditions), qr=TRUE, contrasts=NULL)
ResultsSummary = summary(object=FittedModel_FullDataset, intercept=FALSE, keep.zero.df=TRUE)
AggregatedData = aggregate(NumberData, by=list(Subjects=Subjects,Conditions=Conditions), FUN=mean)
FittedModel_AggregatedData=aov(x ~ Conditions, qr=TRUE, contrasts=NULL, data=AggregatedData)
ConditionMeans = model.tables(x=FittedModel_AggregatedData,type='means',se=FALSE)
TukeyHSD = TukeyHSD(x=FittedModel_AggregatedData,ordered=FALSE, conf.level=PercentageForConfidenceInterval)
{cat('\n\nDESCRIPTIVE STATISTICS\n~~~~~~~~~~~~~~~~~~~~~~\nOverall mean across the entire dataset = ',ConditionMeans$tables$'Grand mean','\n\nMean for each condition:\n',sep='')
nConditions = length(ConditionMeans$tables$Conditions)
for(EachCondition in 1:nConditions){ExtractedNSet = ConditionMeans$n
if(length(ExtractedNSet)==1){ExtractedN=ExtractedNSet}else{ExtractedN = ExtractedNSet[EachCondition]}
if(!is.na(ExtractedN)){CurrentN=ExtractedN}else{CurrentN=ConditionMeans$n$Conditions[1]}
cat(' * Condition '',names(ConditionMeans$tables$Conditions)[EachCondition],'': ',ConditionMeans$tables$Conditions[EachCondition],' (',CurrentN,' observations)\n',sep='')}
cat('\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nA one-way repeated measures ANOVA was run on '',Name_NumberColumn,'' as grouped by '', Name_LabelColumn, '',\n   with '',Name_SubjectColumn,'' used as the error term for individual subjects.\n\n\nRESULTS\n~~~~~~~\nOverall across all conditions of '', Name_LabelColumn, '' (within subjects):\n   F(',ResultsSummary[[2]][[1]]['Conditions','Df'],',',ResultsSummary[[2]][[1]]['Residuals','Df'],') = ',ResultsSummary[[2]][[1]]['Conditions','F value'],', p = ',ResultsSummary[[2]][[1]]['Conditions','Pr(>F)'],'\n\n',sep='')
nComparisons = nrow(TukeyHSD$Conditions)
for(EachComparison in 1:nComparisons){cat('Comparison '',rownames(TukeyHSD$Conditions)[EachComparison],'': Mean = ',TukeyHSD$Conditions[EachComparison,'diff'],', ', 100*PercentageForConfidenceInterval, '% confidence interval [',TukeyHSD$Conditions[EachComparison,'lwr'],', ',TukeyHSD$Conditions[EachComparison,'upr'],'], p = ',TukeyHSD$Conditions[EachComparison,'p adj'],'\n',sep='')}
if(ncol(ResultsSummary[['Error: Subjects']][[1]])>4){cat('\nBetween-subjects effect: F(',ResultsSummary[['Error: Subjects']][[1]]['Conditions','Df'],',',ResultsSummary[['Error: Subjects']][[1]]['Residuals','Df'],') = ',ResultsSummary[['Error: Subjects']][[1]]['Conditions','F value'],', p = ',ResultsSummary[['Error: Subjects']][[1]]['Conditions','Pr(>F)'],'\n\n',sep='')}else{cat('\n\n')}}
show(ConditionMeans)
show(ResultsSummary)
show(TukeyHSD)



________________________
ANOVA_SpecifiedFormula.r



colnames(Dataframe)
Formula = NumberColumn1 ~ LabelColumn1*LabelColumn2
PercentageForConfidenceInterval = 0.95
FittedModel = aov(formula=Formula, data=Dataframe, qr=TRUE, contrasts=NULL) 
ResultsSummary = summary(object=FittedModel,intercept=FALSE,keep.zero.df=TRUE) 
ConditionMeans = model.tables(x=FittedModel,type='means',se=FALSE) 
TukeyHSD = TukeyHSD(x=FittedModel,ordered=FALSE, conf.level=0.95) 
show(ResultsSummary)
show(ConditionMeans)
show(TukeyHSD)



_______________
ANOVA_Two-way.r



colnames(Dataframe)
Name_NumberColumn = 'NumberColumn1'
Name_LabelColumn1 = 'LabelColumn1'
Name_LabelColumn2 = 'LabelColumn2'
NumberData = Dataframe[,Name_NumberColumn]
ConditionSet1 = as.factor(Dataframe[,Name_LabelColumn1])
ConditionSet2 = as.factor(Dataframe[,Name_LabelColumn2])
PercentageForConfidenceInterval = 0.95
FittedModel = aov(NumberData ~ ConditionSet1 + ConditionSet2 + ConditionSet1:ConditionSet2, qr=TRUE, contrasts=NULL) 
ResultsSummary = summary.aov(object=FittedModel,intercept=FALSE,keep.zero.df=TRUE) 
ConditionMeans = model.tables(x=FittedModel,type='means',se=FALSE) 
TukeyHSD = TukeyHSD(x=FittedModel,ordered=FALSE, conf.level=PercentageForConfidenceInterval) 
{ cat('\n\nDESCRIPTIVE STATISTICS\n~~~~~~~~~~~~~~~~~~~~~~\nOverall mean across the entire dataset = ',ConditionMeans$tables$'Grand mean','\n',sep='')
nConditions_Set1 = length(ConditionMeans$tables$ConditionSet1)
if(!is.null(ConditionMeans$tables$ConditionSet1)){
cat('\nMean for each condition in '',Name_LabelColumn1,'':\n',sep='')}
for(EachCondition in 1:nConditions_Set1){
ExtractedNSet = ConditionMeans$n
if(identical(names(ExtractedNSet),c('ConditionSet1','ConditionSet2','ConditionSet1:ConditionSet2'))&!is.list(ExtractedNSet)){ExtractedN=ExtractedNSet['ConditionSet1']}else{ExtractedN = ConditionMeans$n$ConditionSet1[EachCondition]}
if(!is.na(ExtractedN)){CurrentN=ExtractedN}else{CurrentN=ConditionMeans$n$ConditionSet1[1]}
cat(' * Condition '',names(ConditionMeans$tables$ConditionSet1)[EachCondition],'': ',ConditionMeans$tables$ConditionSet1[EachCondition],' (',CurrentN,' observations)\n',sep='')}
nConditions_Set2 = length(ConditionMeans$tables$ConditionSet2)
if(!is.null(ConditionMeans$tables$ConditionSet2)){
cat('\nMean for each condition in '',Name_LabelColumn2,'':\n',sep='')}
for(EachCondition in 1:nConditions_Set2){
ExtractedNSet = ConditionMeans$n
if(identical(names(ExtractedNSet),c('ConditionSet1','ConditionSet2','ConditionSet1:ConditionSet2'))&!is.list(ExtractedNSet)){ExtractedN=ExtractedNSet['ConditionSet2']}else{ExtractedN = ConditionMeans$n$ConditionSet2[EachCondition]}
if(!is.na(ExtractedN)){CurrentN=ExtractedN}else{CurrentN=ConditionMeans$n$ConditionSet2[1]}
cat(' * Condition '',names(ConditionMeans$tables$ConditionSet2)[EachCondition],'': ',ConditionMeans$tables$ConditionSet2[EachCondition],' (',CurrentN,' observations)\n',sep='')}
if(!is.null(ConditionMeans$tables$'ConditionSet1:ConditionSet2')){
cat('\nMean for each combination of conditions:\n')
for(EachCondition1 in 1:nConditions_Set1){for(EachCondition2 in 1:nConditions_Set2){
ExtractedNSet = ConditionMeans$n
if(identical(names(ExtractedNSet),c('ConditionSet1','ConditionSet2','ConditionSet1:ConditionSet2'))&!is.list(ExtractedNSet)){ExtractedN=ExtractedNSet['ConditionSet2']}else{ExtractedN = ConditionMeans$n$'ConditionSet1:ConditionSet2'[EachCondition]}
if(!is.na(ExtractedN)){CurrentN=ExtractedN}else{CurrentN=ConditionMeans$n$'ConditionSet1:ConditionSet2'[1]}
cat(' * '',rownames(ConditionMeans$tables$'ConditionSet1:ConditionSet2')[EachCondition1],'' and '',colnames(ConditionMeans$tables$'ConditionSet1:ConditionSet2')[EachCondition2],'': ',ConditionMeans$tables$'ConditionSet1:ConditionSet2'[EachCondition1,EachCondition2],' (',CurrentN,' observations)\n',sep='')}}}
cat('\n\n') }
cat('\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nA two-way ANOVA was run on '',Name_NumberColumn,'' as grouped by '', Name_LabelColumn1, ''\n   and '',Name_LabelColumn2,''.\n\n\n',sep='')
{cat('\n\nRESULTS\n~~~~~~~\n',sep='')
nSet1Comparisons = nrow(TukeyHSD$ConditionSet1)
if(!is.null(nSet1Comparisons)){
cat('Overall across all conditions of '', Name_LabelColumn1,'':\n   F(',ResultsSummary[[1]][1,'Df'],',',ResultsSummary[[1]][4,'Df'],') = ',ResultsSummary[[1]][1,'F value'],', p = ',ResultsSummary[[1]][1,'Pr(>F)'],'\n\nSpecific comparisons:\n',sep='')
for(EachComparison in 1:nSet1Comparisons){cat(' * ',rownames(TukeyHSD$ConditionSet1)[EachComparison],': Mean = ',TukeyHSD$ConditionSet1[EachComparison,'diff'],', 95% confidence interval [',TukeyHSD$ConditionSet1[EachComparison,'lwr'],', ',TukeyHSD$ConditionSet1[EachComparison,'upr'],'], p = ',TukeyHSD$ConditionSet1[EachComparison,'p adj'],'\n',sep='')}
nSet2Comparisons = nrow(TukeyHSD$ConditionSet2)
if(!is.null(nSet2Comparisons)){
cat('\nOverall across all conditions of '', Name_LabelColumn2,'':\n   F(',ResultsSummary[[1]][2,'Df'],',',ResultsSummary[[1]][4,'Df'],') = ',ResultsSummary[[1]][2,'F value'],', p = ',ResultsSummary[[1]][2,'Pr(>F)'],'\n\nSpecific comparisons:\n',sep='')
for(EachComparison in 1:nSet2Comparisons){cat(' * ',rownames(TukeyHSD$ConditionSet2)[EachComparison],': Mean = ',TukeyHSD$ConditionSet2[EachComparison,'diff'],', ', 100*PercentageForConfidenceInterval, '% confidence interval [',TukeyHSD$ConditionSet2[EachComparison,'lwr'],', ',TukeyHSD$ConditionSet2[EachComparison,'upr'],'], p = ',TukeyHSD$ConditionSet2[EachComparison,'p adj'],'\n',sep='')}
if(!is.na(ResultsSummary[[1]][3,'Pr(>F)'])){cat('\nOverall across all interactions/combinations of conditions:\n   F(',ResultsSummary[[1]][3,'Df'],',',ResultsSummary[[1]][4,'Df'],') = ',ResultsSummary[[1]][3,'F value'],', p = ',ResultsSummary[[1]][3,'Pr(>F)'],'\n\nSpecific interactions:\n',sep='')}}
nInteractions = nrow(TukeyHSD$'ConditionSet1:ConditionSet2')
if(!is.null(nInteractions)){for(EachComparison in 1:nInteractions){cat(' * ',rownames(TukeyHSD$'ConditionSet1:ConditionSet2')[EachComparison],': Mean = ',TukeyHSD$'ConditionSet1:ConditionSet2'[EachComparison,'diff'],', 95% confidence interval [',TukeyHSD$'ConditionSet1:ConditionSet2'[EachComparison,'lwr'],', ',TukeyHSD$'ConditionSet1:ConditionSet2'[EachComparison,'upr'],'], p = ',TukeyHSD$'ConditionSet1:ConditionSet2'[EachComparison,'p adj'],'\n',sep='')}}
cat('\n')}}
show(ConditionMeans)
show(ResultsSummary)
show(TukeyHSD)



________________________________
ANOVA_Two-way_RepeatedMeasures.r



colnames(Dataframe)
Name_NumberColumn = 'NumberColumn'
Name_LabelColumn1 = 'LabelColumn1'
Name_LabelColumn2 = 'LabelColumn2'
Name_SubjectColumn = 'SubjectColumn'
NumberData = Dataframe[,Name_NumberColumn]
ConditionSet1 = as.factor(Dataframe[,Name_LabelColumn1])
ConditionSet2 = as.factor(Dataframe[,Name_LabelColumn2])
Subjects      = as.factor(Dataframe[,Name_SubjectColumn])
PercentageForConfidenceInterval = 0.95
FittedModel_FullDataset=aov(NumberData ~ ConditionSet1*ConditionSet2 + Error(Subjects/(ConditionSet1*ConditionSet2)), qr=TRUE, contrasts=NULL)
ResultsSummary = summary(object=FittedModel_FullDataset,intercept=FALSE,keep.zero.df=TRUE)
AggregatedData = aggregate(NumberData, by=list(Subjects=Subjects,ConditionSet1=ConditionSet1,ConditionSet2=ConditionSet2), FUN=mean)
FittedModel_AggregatedData=aov(x ~ ConditionSet1*ConditionSet2, qr=TRUE, contrasts=NULL, data=AggregatedData)
ConditionMeans = model.tables(x=FittedModel_AggregatedData,type='means',se=FALSE)
TukeyHSD = TukeyHSD(x=FittedModel_AggregatedData,ordered=FALSE, conf.level=PercentageForConfidenceInterval)
{cat('\n\nDESCRIPTIVE STATISTICS\n~~~~~~~~~~~~~~~~~~~~~~\nOverall mean across the entire dataset = ',ConditionMeans$tables$'Grand mean','\n',sep='')
nConditions_Set1 = length(ConditionMeans$tables$ConditionSet1)
if(!is.null(ConditionMeans$tables$ConditionSet1)){
cat('\nMean for each condition in '',Name_LabelColumn1,'':\n',sep='')
for(EachCondition in 1:nConditions_Set1){
ExtractedNSet = ConditionMeans$n
if(identical(names(ExtractedNSet),c('ConditionSet1','ConditionSet2','ConditionSet1:ConditionSet2'))&!is.list(ExtractedNSet)){ExtractedN=ExtractedNSet['ConditionSet1']}else{ExtractedN = ConditionMeans$n$ConditionSet1[EachCondition]}
if(!is.na(ExtractedN)){CurrentN=ExtractedN}else{CurrentN=ConditionMeans$n$ConditionSet1[1]}
cat(' * Condition '',names(ConditionMeans$tables$ConditionSet1)[EachCondition],'': ',ConditionMeans$tables$ConditionSet1[EachCondition],' (',CurrentN,' observations)\n',sep='')}
nConditions_Set2 = length(ConditionMeans$tables$ConditionSet2) }
if(!is.null(ConditionMeans$tables$ConditionSet2)){
cat('\nMean for each condition in '',Name_LabelColumn2,'':\n',sep='')
for(EachCondition in 1:nConditions_Set2){
ExtractedNSet = ConditionMeans$n
if(identical(names(ExtractedNSet),c('ConditionSet1','ConditionSet2','ConditionSet1:ConditionSet2'))&!is.list(ExtractedNSet)){ExtractedN=ExtractedNSet['ConditionSet1']}else{ExtractedN = ConditionMeans$n$ConditionSet1[EachCondition]}
if(!is.na(ExtractedN)){CurrentN=ExtractedN}else{CurrentN=ConditionMeans$n$ConditionSet2[1]}
cat(' * Condition '',names(ConditionMeans$tables$ConditionSet2)[EachCondition],'': ',ConditionMeans$tables$ConditionSet2[EachCondition],' (',CurrentN,' observations)\n',sep='')}}
if(!is.null(ConditionMeans$tables$'ConditionSet1:ConditionSet2')){
cat('\nMean for each combination of conditions:\n')
for(EachCondition1 in 1:nConditions_Set1){for(EachCondition2 in 1:nConditions_Set2){
ExtractedNSet = ConditionMeans$n
if(identical(names(ExtractedNSet),c('ConditionSet1','ConditionSet2','ConditionSet1:ConditionSet2'))&!is.list(ExtractedNSet)){ExtractedN=ExtractedNSet['ConditionSet1:ConditionSet2']}else{ConditionMeans$n$'ConditionSet1:ConditionSet2'[EachCondition1,EachCondition2]}
cat(' * '',rownames(ConditionMeans$tables$'ConditionSet1:ConditionSet2')[EachCondition1],'' and '',colnames(ConditionMeans$tables$'ConditionSet1:ConditionSet2')[EachCondition2],'': ',ConditionMeans$tables$'ConditionSet1:ConditionSet2'[EachCondition1,EachCondition2],' (',ExtractedN,' observations)\n',sep='')}}}
cat('\n\n')}
cat('\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nA two-way factorial repeated measures ANOVA was run on '',Name_NumberColumn,'' as grouped by\n   '', Name_LabelColumn1,'' and '', Name_LabelColumn2, '', with '',Name_SubjectColumn,'' used as the error term for\n   individual subjects.\n\n\n',sep='')
{ cat('\n\nRESULTS\n~~~~~~~\nOverall across all conditions of '', Name_LabelColumn1,'':\n   F(',ResultsSummary[['Error: Subjects:ConditionSet1']][[1]]['ConditionSet1','Df'],',',ResultsSummary[['Error: Subjects:ConditionSet1']][[1]]['Residuals','Df'],') = ',ResultsSummary[['Error: Subjects:ConditionSet1']][[1]]['ConditionSet1','F value'],', p = ',ResultsSummary[['Error: Subjects:ConditionSet1']][[1]]['ConditionSet1','Pr(>F)'],'\n\nSpecific comparisons:\n',sep='')
 nSet1Comparisons = nrow(TukeyHSD$ConditionSet1)
 for(EachComparison in 1:nSet1Comparisons){cat(' * ',rownames(TukeyHSD$ConditionSet1)[EachComparison],': Mean = ',TukeyHSD$ConditionSet1[EachComparison,'diff'],', ', 100*PercentageForConfidenceInterval, '% confidence interval [',TukeyHSD$ConditionSet1[EachComparison,'lwr'],', ',TukeyHSD$ConditionSet1[EachComparison,'upr'],'], p = ',TukeyHSD$ConditionSet1[EachComparison,'p adj'],'\n',sep='')}
 cat('\nOverall across all conditions of '', Name_LabelColumn2,'':\n   F(',ResultsSummary[['Error: Subjects:ConditionSet2']][[1]]['ConditionSet2','Df'],',',ResultsSummary[['Error: Subjects:ConditionSet2']][[1]]['Residuals','Df'],') = ',ResultsSummary[['Error: Subjects:ConditionSet2']][[1]]['ConditionSet2','F value'],', p = ',ResultsSummary[['Error: Subjects:ConditionSet2']][[1]]['ConditionSet2','Pr(>F)'],'\n\nSpecific comparisons:\n',sep='')
 nSet2Comparisons = nrow(TukeyHSD$ConditionSet2)
 for(EachComparison in 1:nSet2Comparisons){cat(' * ',rownames(TukeyHSD$ConditionSet2)[EachComparison],': Mean = ',TukeyHSD$ConditionSet2[EachComparison,'diff'],', ', 100*PercentageForConfidenceInterval, '% confidence interval [',TukeyHSD$ConditionSet2[EachComparison,'lwr'],', ',TukeyHSD$ConditionSet2[EachComparison,'upr'],'], p = ',TukeyHSD$ConditionSet2[EachComparison,'p adj'],'\n',sep='')}
 if(!is.na(ResultsSummary[['Error: Subjects:ConditionSet1:ConditionSet2']][[1]]['ConditionSet1:ConditionSet2','Pr(>F)'])){cat('\nOverall across all interactions/combinations of conditions:\n   F(',ResultsSummary[['Error: Subjects:ConditionSet1:ConditionSet2']][[1]]['ConditionSet1:ConditionSet2','Df'],',',ResultsSummary[['Error: Subjects:ConditionSet1:ConditionSet2']][[1]]['Residuals','Df'],') = ',ResultsSummary[['Error: Subjects:ConditionSet1:ConditionSet2']][[1]]['ConditionSet1:ConditionSet2','F value'],', p = ',ResultsSummary[['Error: Subjects:ConditionSet1:ConditionSet2']][[1]]['ConditionSet1:ConditionSet2','Pr(>F)'],'\n\nSpecific interactions:\n',sep='')
 nInteractions = nrow(TukeyHSD$'ConditionSet1:ConditionSet2')
 for(EachComparison in 1:nInteractions){cat(' * ',rownames(TukeyHSD$'ConditionSet1:ConditionSet2')[EachComparison],': Mean = ',TukeyHSD$'ConditionSet1:ConditionSet2'[EachComparison,'diff'],', ', 100*PercentageForConfidenceInterval, '% confidence interval [',TukeyHSD$'ConditionSet1:ConditionSet2'[EachComparison,'lwr'],', ',TukeyHSD$'ConditionSet1:ConditionSet2'[EachComparison,'upr'],'], p = ',TukeyHSD$'ConditionSet1:ConditionSet2'[EachComparison,'p adj'],'\n',sep='')}
 cat('\nBetween-subjects effect: F(',ResultsSummary[['Error: Subjects']][[1]]['ConditionSet1','Df'],',',ResultsSummary[['Error: Subjects']][[1]]['Residuals','Df'],') = ',ResultsSummary[['Error: Subjects']][[1]]['ConditionSet1','F value'],', p = ',ResultsSummary[['Error: Subjects']][[1]]['ConditionSet1','Pr(>F)'],'\n\n',sep='')}
 cat('\n') }
show(ConditionMeans)
show(ResultsSummary)
show(TukeyHSD)



_________________
CorrelationTest.r



colnames(Dataframe)
DataName1 = 'ColumnName1'
DataName2 = 'ColumnName2'
NumberData1 = Dataframe[,DataName1]
NumberData2 = Dataframe[,DataName2]
Directionality_AlternativeHypothesis = 'two.sided'
PercentageForConfidenceInterval = 0.95
Results = cor.test(x=NumberData1, y=NumberData2, alternative=Directionality_AlternativeHypothesis, method='pearson', conf.level=PercentageForConfidenceInterval)
if(Results$alternative=='two.sided'){AlternativeText='not equal to'}
if(Results$alternative=='greater'){AlternativeText='greater than '}
if(Results$alternative=='less'){AlternativeText='less than'}
cat('\n\nDESCRIPTIVE STATISTICS\n~~~~~~~~~~~~~~~~~~~~~~\nThe ',Results$method,' between ',DataName1,' and ', DataName2,' is ', as.numeric(Results$estimate),'.\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nA correlation test was run:\n - Null hypothesis: The true correlation is 0.\n - Alternative hypothesis: The true correlation is ',AlternativeText,' 0.\n\nRESULTS\n~~~~~~~\nThe ',100*attributes(Results$conf.int)$conf.level,'% confidence interval ranges from ', as.numeric(Results$conf.int)[1], ' to ', as.numeric(Results$conf.int)[2],'.\nt(', as.numeric(Results$parameter), ')=', as.numeric(Results$statistic), ', p=',Results$p.value,'\n\n\n',sep='')
show(Results)
cor.test(x=NumberData1, y=NumberData2, alternative=Directionality_AlternativeHypothesis, method='kendall', exact = FALSE, continuity = FALSE)
cor.test(x=NumberData1, y=NumberData2, alternative=Directionality_AlternativeHypothesis, method='spearman', exact = FALSE, continuity = FALSE)



_____________________________________
CreateBarplot_MultipleNumberColumns.r



colnames(Dataframe)
NumberColumnNames = BarLabels = c('NumberColumn1','NumberColumn2','NumberColumn3')
BarLabels = c('My first column', 'My second column', 'My third column')
NumberData = Dataframe[,NumberColumnNames]
MainTitle = 'Barplot'
ShouldThisBarplotBeHorizontal = FALSE
xAxisLimits = NULL
yAxisLimits = NULL
xAxisLabel = ''
yAxisLabel = ''
SpaceBetweenBars = 0.2
BarFillColors = NULL
FontSizeAdjustment_NumberScale = 1
FontSizeAdjustment_BarLabels = 1
barplot(height=apply(X=NumberData,MARGIN=2,FUN='mean'), width=1, space=SpaceBetweenBars, legend.text=NULL, names.arg=BarLabels, beside=TRUE, horiz=ShouldThisBarplotBeHorizontal, density=NULL, col=BarFillColors, border='black', main=MainTitle, sub=NULL, xlab=xAxisLabel, ylab=yAxisLabel, xlim=xAxisLimits, ylim=yAxisLimits, xpd=TRUE, log='', axes=TRUE, axisnames=TRUE, cex.axis=FontSizeAdjustment_NumberScale, cex.names=FontSizeAdjustment_BarLabels, plot=TRUE, axis.lty=0, offset=0, add=FALSE, args.legend = NULL)
Means = apply(X=NumberData,MARGIN=2,FUN='mean')
SDs = apply(X=NumberData,MARGIN=2,FUN='sd')
Midpoints = barplot(height=Means, width=1, space=SpaceBetweenBars, beside=TRUE, plot=FALSE)
MinusSD = Means-SDs
PlusSD = Means+SDs
if(ShouldThisBarplotBeHorizontal==FALSE){ x0 = Midpoints
x1 = Midpoints
y0 = MinusSD
y1 = PlusSD }
if(ShouldThisBarplotBeHorizontal==TRUE){ x0 = MinusSD
x1 = PlusSD
y0 = Midpoints
y1 = Midpoints }
arrows(x0=x0, y0=y0, x1=x1, y1=y1, length = 0.25, angle=90, code=3, col = 'black', lty = 'solid', lwd=1, xpd=TRUE)



________________________________________________
CreateBarplot_OneNumberColumnAndOneLabelColumn.r



colnames(Dataframe)
NumberData = Dataframe[,'NumberColumn1']
IdentifierLabels = Dataframe[,'LabelColumn']
BarLabels = levels(IdentifierLabels)
levels(IdentifierLabels)
BarLabels = c('My first condition', 'My second condition', 'My third condition')
MainTitle = 'Barplot'
ShouldThisBarplotBeHorizontal = FALSE
xAxisLimits = NULL
yAxisLimits = NULL
xAxisLabel = ''
yAxisLabel = ''
SpaceBetweenBars = 0.2
BarFillColors = NULL
FontSizeAdjustment_NumberScale = 1
FontSizeAdjustment_BarLabels = 1
barplot(height=tapply(X=NumberData,INDEX=IdentifierLabels,FUN='mean'), width=1, space=SpaceBetweenBars, legend.text=NULL, names.arg=BarLabels, beside=TRUE, horiz=ShouldThisBarplotBeHorizontal, density=NULL, col=BarFillColors, border='black', main=MainTitle, sub=NULL, xlab=xAxisLabel, ylab=yAxisLabel, xlim=xAxisLimits, ylim=yAxisLimits, xpd=TRUE, log='', axes=TRUE, axisnames=TRUE, cex.axis=FontSizeAdjustment_NumberScale, cex.names=FontSizeAdjustment_BarLabels, plot=TRUE, axis.lty=0, offset=0, add=FALSE, args.legend = NULL)
Means = tapply(X=NumberData,INDEX=IdentifierLabels,FUN='mean')
SDs = tapply(X=NumberData,INDEX=IdentifierLabels,FUN='sd')
Midpoints = barplot(height=Means, width=1, space=SpaceBetweenBars, beside=TRUE, plot=FALSE)
MinusSD = Means-SDs
PlusSD = Means+SDs
if(ShouldThisBarplotBeHorizontal==FALSE){ x0 = Midpoints
x1 = Midpoints
y0 = MinusSD
y1 = PlusSD }
if(ShouldThisBarplotBeHorizontal==TRUE){ x0 = MinusSD
x1 = PlusSD
y0 = Midpoints
y1 = Midpoints }
arrows(x0=x0, y0=y0, x1=x1, y1=y1, length = 0.25, angle=90, code=3, col = 'black', lty = 'solid', lwd=1, xpd=TRUE)



_________________________________________________
CreateBarplot_OneNumberColumnAndTwoLabelColumns.r



colnames(Dataframe)
NumberData = Dataframe[,'NumberColumn1']
ClusteringConditions = Dataframe[,'LabelColumn1']
ColorCodedConditions = Dataframe[,'LabelColumn2']
Labels_ClusteringConditions = levels(ClusteringConditions)
Labels_ColorCodedConditions = levels(ColorCodedConditions)
levels(ClusteringConditions)
levels(ColorCodedConditions)
Labels_ClusteringConditions = c('Cluster one', 'Cluster two', 'Cluster three')
Labels_ColorCodedConditions = c('Color-condition one', 'Color-condition two')
MainTitle = 'Barplot'
ShouldThisBarplotBeHorizontal = FALSE
xAxisLimits = NULL
yAxisLimits = NULL
xAxisLabel = ''
yAxisLabel = ''
SpaceBetweenBars_WithinCluster = 0
SpaceBetweenBars_BetweenClusters = 1
BarFillColors = NULL
FontSizeAdjustment_NumberScale = 1
FontSizeAdjustment_BarLabels = 1
barplot(height=tapply(X=NumberData,INDEX=list(ColorCodedConditions,ClusteringConditions),FUN='mean'), width=1, space=c(SpaceBetweenBars_WithinCluster, SpaceBetweenBars_BetweenClusters), legend.text=NULL, names.arg=Labels_ClusteringConditions, beside=TRUE, horiz=ShouldThisBarplotBeHorizontal, density=NULL, col=BarFillColors, border='black', main=MainTitle, sub=NULL, xlab=xAxisLabel, ylab=yAxisLabel, xlim=xAxisLimits, ylim=yAxisLimits, xpd=TRUE, log='', axes=TRUE, axisnames=TRUE, cex.axis=FontSizeAdjustment_NumberScale, cex.names=FontSizeAdjustment_BarLabels, plot=TRUE, axis.lty=0, offset=0, add=FALSE, args.legend = NULL)
Means = tapply(X=NumberData,INDEX=list(ColorCodedConditions,ClusteringConditions),FUN='mean')
SDs = tapply(X=NumberData,INDEX=list(ColorCodedConditions,ClusteringConditions),FUN='sd')
Midpoints = barplot(height=Means, width=1, space=c(SpaceBetweenBars_WithinCluster, SpaceBetweenBars_BetweenClusters), beside=TRUE, plot=FALSE)
MinusSD = Means-SDs
PlusSD = Means+SDs
if(ShouldThisBarplotBeHorizontal==FALSE){ x0 = Midpoints
x1 = Midpoints
y0 = MinusSD
y1 = PlusSD }
if(ShouldThisBarplotBeHorizontal==TRUE){ x0 = MinusSD
x1 = PlusSD
y0 = Midpoints
y1 = Midpoints }
arrows(x0=c(x0), y0=c(y0), x1=c(x1), y1=c(y1), length = 0.25, angle=90, code=3, col = 'black', lty = 'solid', lwd=1, xpd=TRUE)
LegendTitle = 'Title'
HorizontalLegend = FALSE
HorizontalSpan=(par('usr')[1]-par('usr')[2])/(par('plt')[1]-par('plt')[2])
LeftEdge=par('usr')[1]-HorizontalSpan*par('plt')[1]
RightEdge=LeftEdge+HorizontalSpan
VerticalSpan=(par('usr')[3]-par('usr')[4])/(par('plt')[3]-par('plt')[4])
BottomEdge=par('usr')[3]-VerticalSpan*par('plt')[3]
TopEdge=BottomEdge+VerticalSpan
Legend=legend(x=par('usr')[1],y=par('usr')[4],legend=Labels_ColorCodedConditions,fill=BarFillColors,title=LegendTitle,horiz=HorizontalLegend,plot=FALSE)
width=par('fin')[1]*Legend$rect$w/(RightEdge-LeftEdge)
height=par('fin')[2]*Legend$rect$h/(TopEdge-BottomEdge)
OuterMargin=0.1
dev.new(width=width+2*OuterMargin,height=height+2*OuterMargin)
par(mai=rep(OuterMargin,times=4))
plot.default(x=NULL,y=NULL,xlim=c(0,width),ylim=c(height,0),axes=FALSE,ann=FALSE,xaxs='i',yaxs='i')
legend(x=0,y=0,legend=Labels_ColorCodedConditions,fill=BarFillColors,border='black',bg='transparent',box.lty='solid',box.lwd=1,box.col='black',text.col='black',title=LegendTitle,title.col='black',horiz=HorizontalLegend,xpd=TRUE)



_____________________________________
CreateBoxplot_MultipleNumberColumns.r



colnames(Dataframe)
NumberColumnNames=BoxLabels=c('NumberColumn1','NumberColumn2','NumberColumn3')
BoxLabels=c('My first column', 'My second column', 'My third column')
NumberData=Dataframe[,NumberColumnNames]
MainTitle = 'Boxplot'
ShouldThisBoxplotBeHorizontal = FALSE
xAxisLimits = NULL
yAxisLimits = NULL
xAxisLabel = ''
yAxisLabel = ''
OutlierThreshold=1.5
AddMedianRobustnessIndentations = FALSE
BoxWidth = 0.8
BoxFillColors = NULL
boxplot(x=NumberData, names=BoxLabels, main=MainTitle, horizontal=ShouldThisBoxplotBeHorizontal, xlim=xAxisLimits, ylim=yAxisLimits, xlab=xAxisLabel, ylab=yAxisLabel, range=OutlierThreshold, notch=AddMedianRobustnessIndentations, boxwex=BoxWidth, boxfill=BoxFillColors, plot=TRUE, add=FALSE, show.names=TRUE, axes=TRUE, log='', frame.plot=TRUE, width=NULL, varwidth=FALSE, staplewex=0.5, notch.frac=0.5, border='black', medlty='solid', medlwd=3, medpch=NA, boxlty = 'solid', boxlwd=1, whisklty='dashed', whisklwd=1, staplelty='solid', staplelwd=1, outline=TRUE, outpch=1, outcex=1, outlty='blank', pars=NULL)



________________________________________________
CreateBoxplot_OneNumberColumnAndOneLabelColumn.r



colnames(Dataframe)
NumberData = Dataframe[,'NumberColumn1']
IdentifierLabels = Dataframe[,'LabelColumn']
BoxLabels = levels(IdentifierLabels)
levels(IdentifierLabels)
BoxLabels = c('My first condition', 'My second condition', 'My third condition')
MainTitle = 'Boxplot'
ShouldThisBoxplotBeHorizontal = FALSE
xAxisLimits = NULL
yAxisLimits = NULL
xAxisLabel = ''
yAxisLabel = ''
OutlierThreshold=1.5
AddMedianRobustnessIndentations = FALSE
BoxWidth = 0.8
BoxFillColors = NULL
boxplot(formula=NumberData~IdentifierLabels, names=BoxLabels, main=MainTitle, horizontal=ShouldThisBoxplotBeHorizontal, xlim=xAxisLimits, ylim=yAxisLimits, xlab=xAxisLabel, ylab=yAxisLabel, range=OutlierThreshold, notch=AddMedianRobustnessIndentations, boxwex=BoxWidth, boxfill=BoxFillColors, plot=TRUE, add=FALSE, show.names=TRUE, axes=TRUE, log='', frame.plot=TRUE, width=NULL, varwidth=FALSE, staplewex=0.5, notch.frac=0.5, border='black', medlty='solid', medlwd=3, medpch=NA, boxlty = 'solid', boxlwd=1, whisklty='dashed', whisklwd=1, staplelty='solid', staplelwd=1, outline=TRUE, outpch=1, outcex=1, outlty='blank', pars=NULL)



_________________
CreateHistogram.r



colnames(Dataframe)
NumberData = Dataframe[,'NumberColumn']
MainTitle = 'Histogram'
NumberOfBars = 'Sturges'
xAxisLabel = ''
PlotAsFrequencyCounts = FALSE
yAxisLimits = NULL
LabelsAboveBars = FALSE
BarFillColor = NULL
DensityOfShadingLines = NULL
AngleOfShadingLines = 45
BarBorderColor = NULL
hist(x=NumberData, main=MainTitle, breaks=NumberOfBars, xlab=xAxisLabel, freq=PlotAsFrequencyCounts, ylim=yAxisLimits, labels=LabelsAboveBars, col=BarFillColor, density=DensityOfShadingLines, angle=AngleOfShadingLines, border=BarBorderColor, plot=TRUE, axes=TRUE, include.lowest=TRUE, right=TRUE)
NumberOfBars = 'Scott' 
NumberOfBars = 'Freedman-Diaconis' 
hist(x=NumberData, breaks=NumberOfBars, plot=FALSE)$counts
hist(x=NumberData, breaks=NumberOfBars, plot=FALSE)$density
hist(x=NumberData, breaks=NumberOfBars, plot=FALSE)$breaks
hist(x=NumberData, breaks=NumberOfBars, plot=FALSE)$mids



___________________________________
CreateScatterplot_AllCodedTheSame.r



colnames(Dataframe)
NumberDataX = Dataframe[,'NumberColumn1']
NumberDataY = Dataframe[,'NumberColumn2']
MainTitle = 'Scatterplot'
xAxisLimits = NULL
yAxisLimits = NULL
xAxisLabel = ''
yAxisLabel = ''
PlotWhichAxesLogarithmically = ''
PointSymbol = 1
PointColor = 'black'
PointSizeModifier = 1
GridlineType = 'blank'
GridlineColor = 'lightgrey'
GridlineWidthModifier = 1
plot.default(x=NumberDataX, y=NumberDataY, main=MainTitle, xlim=xAxisLimits, ylim=yAxisLimits, xlab=xAxisLabel, ylab=yAxisLabel, log=PlotWhichAxesLogarithmically, pch=PointSymbol, col=PointColor, cex=PointSizeModifier, type='p', ann=TRUE, axes=TRUE, frame.plot=TRUE, panel.first=grid(lty=GridlineType, col=GridlineColor, lwd=GridlineWidthModifier), panel.last=NULL, asp=NA)
RegressionLineType = 'solid'
RegressionLineColor = 'red'
RegressionLineWidthModifier = 1
abline(reg=lm(formula=NumberDataY~NumberDataX),lty=RegressionLineType,col=RegressionLineColor,lwd=RegressionLineWidthModifier)



________________________________
CreateScatterplot_CodedByColor.r



colnames(Dataframe)
NumberDataX = Dataframe[,'NumberColumn1']
NumberDataY = Dataframe[,'NumberColumn2']
LabelColumn_PointColor = as.factor(Dataframe[,'LabelColumnName'])
LegendLabels = levels(LabelColumn_PointColor)
levels(LabelColumn_PointColor)
LegendLabels = c('My first condition', 'My second condition', 'My third condition')
MainTitle = 'Scatterplot'
xAxisLimits = NULL
yAxisLimits = NULL
xAxisLabel = ''
yAxisLabel = ''
PlotWhichAxesLogarithmically = ''
PointSymbol = 1
levels(LabelColumn_PointColor)
PointColors=c('black','red','green3','blue','cyan','magenta','yellow','gray')
PointSizeModifier = 1
GridlineType = 'dotted'
GridlineColor = 'lightgrey'
GridlineWidthModifier = 1
plot.default(x=NumberDataX, y=NumberDataY, main=MainTitle, xlim=xAxisLimits, ylim=yAxisLimits, xlab=xAxisLabel, ylab=yAxisLabel, log=PlotWhichAxesLogarithmically, pch=PointSymbol, col=PointColors[LabelColumn_PointColor], cex=PointSizeModifier, type='p', ann=TRUE, axes=TRUE, frame.plot=TRUE, panel.first=grid(lty=GridlineType, col=GridlineColor, lwd=GridlineWidthModifier), panel.last=NULL, asp=NA)
RegressionLineType = c('solid','dashed','dotted','dotdash','longdash','twodash')
RegressionLineWidthModifier = 1
Groups = levels(LabelColumn_PointColor)
nGroups = length(Groups)
for(EachGroup in 1:nGroups){Filter = ( LabelColumn_PointColor == Groups[EachGroup] )
Regression = lm(formula=NumberDataY[Filter]~NumberDataX[Filter])
abline(reg=Regression,lty=RegressionLineType[EachGroup],col=PointColors[EachGroup],lwd=RegressionLineWidthModifier)}
LegendTitle = 'Title'
HorizontalLegend = FALSE
if(as.logical(sum(objects()=='RegressionLineType'))){LegendLines=RegressionLineType[1:length(levels(LabelColumn_PointColor))]}else{LegendLines=NULL}
HorizontalSpan=(par('usr')[1]-par('usr')[2])/(par('plt')[1]-par('plt')[2])
LeftEdge=par('usr')[1]-HorizontalSpan*par('plt')[1]
RightEdge=LeftEdge+HorizontalSpan
VerticalSpan=(par('usr')[3]-par('usr')[4])/(par('plt')[3]-par('plt')[4])
BottomEdge=par('usr')[3]-VerticalSpan*par('plt')[3]
TopEdge=BottomEdge+VerticalSpan
Legend=legend(x=par('usr')[1],y=par('usr')[4],legend=LegendLabels,pch=PointSymbol,lty=LegendLines,pt.cex=PointSizeModifier,title=LegendTitle,horiz=HorizontalLegend,plot=FALSE)
width=par('fin')[1]*Legend$rect$w/(RightEdge-LeftEdge)
height=par('fin')[2]*Legend$rect$h/(TopEdge-BottomEdge)
OuterMargin=0.1
dev.new(width=width+2*OuterMargin,height=height+2*OuterMargin)
par(mai=rep(OuterMargin,times=4))
plot.default(x=NULL,y=NULL,xlim=c(0,width),ylim=c(height,0),axes=FALSE,ann=FALSE,xaxs='i',yaxs='i')
legend(x=0,y=0,legend=LegendLabels,pch=PointSymbol,col=PointColors[1:length(levels(LabelColumn_PointColor))],lty=LegendLines,pt.cex=PointSizeModifier,title=LegendTitle,horiz=HorizontalLegend,border='black',bg='transparent',box.lty='solid',box.lwd=1,box.col='black',text.col='black',title.col='black',xpd=TRUE)



_________________________________________
CreateScatterplot_CodedByColorAndSymbol.r



colnames(Dataframe)
NumberDataX = Dataframe[,'NumberColumn1']
NumberDataY = Dataframe[,'NumberColumn2']
LabelColumn_PointSymbol = as.factor(Dataframe[,'LabelColumnName'])
LabelColumn_PointColor  = as.factor(Dataframe[,'LabelColumnName'])
LegendLabels_PointSymbol = levels(LabelColumn_PointSymbol)
LegendLabels_PointColor  = levels(LabelColumn_PointColor )
levels(LabelColumn_PointSymbol)
levels(LabelColumn_PointColor )
LegendLabels_PointSymbol = c('Condition One', 'Condition Two', 'Condition Three')
LegendLabels_PointColor  = c('Group A', 'Group B')
LabelSeparator = ', '
MainTitle = 'Scatterplot'
xAxisLimits = NULL
yAxisLimits = NULL
xAxisLabel = ''
yAxisLabel = ''
PlotWhichAxesLogarithmically = ''
levels(LabelColumn_PointSymbol)
PointSymbols = c(1, 0, 2, 5, 16, 15, 17, 18)
levels(LabelColumn_PointColor)
PointColors=c('black','red','green3','blue','cyan','magenta','yellow','gray')
PointSizeModifier = 1
GridlineType = 'blank'
GridlineColor = 'lightgrey'
GridlineWidthModifier = 1
plot.default(x=NumberDataX, y=NumberDataY, main=MainTitle, xlim=xAxisLimits, ylim=yAxisLimits, xlab=xAxisLabel, ylab=yAxisLabel, log=PlotWhichAxesLogarithmically, pch=PointSymbols[LabelColumn_PointSymbol], col=PointColors[LabelColumn_PointColor], cex=PointSizeModifier, type='p', ann=TRUE, axes=TRUE, frame.plot=TRUE, panel.first=grid(lty=GridlineType, col=GridlineColor, lwd=GridlineWidthModifier), panel.last=NULL, asp=NA)
LegendTitle = 'Title'
HorizontalLegend = FALSE
LabelSet=paste(rep(LegendLabels_PointSymbol,each=length(LegendLabels_PointColor)),rep(LegendLabels_PointColor,times=length(LegendLabels_PointSymbol)),sep=LabelSeparator)
pch=rep(PointSymbols[1:length(LegendLabels_PointSymbol)],each =length(LegendLabels_PointColor) )
col=rep(PointColors [1:length(LegendLabels_PointColor )],times=length(LegendLabels_PointSymbol) )
HorizontalSpan=(par('usr')[1]-par('usr')[2])/(par('plt')[1]-par('plt')[2])
LeftEdge=par('usr')[1]-HorizontalSpan*par('plt')[1]
RightEdge=LeftEdge+HorizontalSpan
VerticalSpan=(par('usr')[3]-par('usr')[4])/(par('plt')[3]-par('plt')[4])
BottomEdge=par('usr')[3]-VerticalSpan*par('plt')[3]
TopEdge=BottomEdge+VerticalSpan
Legend=legend(x=par('usr')[1],y=par('usr')[4],legend=LabelSet,pch=pch,pt.cex=PointSizeModifier,title=LegendTitle,horiz=HorizontalLegend,plot=FALSE)
width=par('fin')[1]*Legend$rect$w/(RightEdge-LeftEdge)
height=par('fin')[2]*Legend$rect$h/(TopEdge-BottomEdge)
OuterMargin=0.1
dev.new(width=width+2*OuterMargin,height=height+2*OuterMargin)
par(mai=rep(OuterMargin,times=4))
plot.default(x=NULL,y=NULL,xlim=c(0,width),ylim=c(height,0),axes=FALSE,ann=FALSE,xaxs='i',yaxs='i')
legend(x=0,y=0,legend=LabelSet,pch=pch,col=col,pt.cex=PointSizeModifier,title=LegendTitle,horiz=HorizontalLegend,border='black',bg='transparent',box.lty='solid',box.lwd=1,box.col='black',text.col='black',title.col='black',xpd=TRUE)



__________________________________________________
CreateScatterplot_CodedBySymbol(Black-and-White).r



colnames(Dataframe)
NumberDataX = Dataframe[,'NumberColumn1']
NumberDataY = Dataframe[,'NumberColumn2']
LabelColumn_PointSymbol = as.factor(Dataframe[,'LabelColumnName'])
LegendLabels = levels(LabelColumn_PointSymbol)
levels(LabelColumn_PointSymbol)
LegendLabels = c('My first condition', 'My second condition', 'My third condition')
MainTitle = 'Scatterplot'
xAxisLimits = NULL
yAxisLimits = NULL
xAxisLabel = ''
yAxisLabel = ''
PlotWhichAxesLogarithmically = ''
PointSymbols = c(1, 0, 2, 5, 16, 15, 17, 18)
PointSizeModifier = 1
plot.default(x=NumberDataX, y=NumberDataY, main=MainTitle, xlim=xAxisLimits, ylim=yAxisLimits, xlab=xAxisLabel, ylab=yAxisLabel, log=PlotWhichAxesLogarithmically, pch=PointSymbols[LabelColumn_PointSymbol], col='black', cex=PointSizeModifier, type='p', ann=TRUE, axes=TRUE, frame.plot=TRUE, panel.first=NULL, panel.last=NULL, asp=NA)
RegressionLineType = c('solid','dashed','dotted','dotdash','longdash','twodash')
RegressionLineWidthModifier = 1
Groups = levels(LabelColumn_PointSymbol)
nGroups = length(Groups)
for(EachGroup in 1:nGroups){Filter = ( LabelColumn_PointSymbol == Groups[EachGroup] )
Regression = lm(formula=NumberDataY[Filter]~NumberDataX[Filter])
abline(reg=Regression,lty=RegressionLineType[EachGroup],col='black',lwd=RegressionLineWidthModifier)}
LegendTitle = 'Title'
HorizontalLegend = FALSE
pch=PointSymbols[1:length(LegendLabels)]
if(as.logical(sum(objects()=='RegressionLineType'))){LegendLines=RegressionLineType[1:length(levels(LabelColumn_PointSymbol))]}else{LegendLines=NULL}
HorizontalSpan=(par('usr')[1]-par('usr')[2])/(par('plt')[1]-par('plt')[2])
LeftEdge=par('usr')[1]-HorizontalSpan*par('plt')[1]
RightEdge=LeftEdge+HorizontalSpan
VerticalSpan=(par('usr')[3]-par('usr')[4])/(par('plt')[3]-par('plt')[4])
BottomEdge=par('usr')[3]-VerticalSpan*par('plt')[3]
TopEdge=BottomEdge+VerticalSpan
Legend=legend(x=par('usr')[1],y=par('usr')[4],legend=LegendLabels,pch=pch,lty=LegendLines,pt.cex=PointSizeModifier,title=LegendTitle,horiz=HorizontalLegend,plot=FALSE)
width=par('fin')[1]*Legend$rect$w/(RightEdge-LeftEdge)
height=par('fin')[2]*Legend$rect$h/(TopEdge-BottomEdge)
OuterMargin=0.1
dev.new(width=width+2*OuterMargin,height=height+2*OuterMargin)
par(mai=rep(OuterMargin,times=4))
plot.default(x=NULL,y=NULL,xlim=c(0,width),ylim=c(height,0),axes=FALSE,ann=FALSE,xaxs='i',yaxs='i')
legend(x=0,y=0,legend=LegendLabels,pch=pch,lty=LegendLines,pt.cex=PointSizeModifier,title=LegendTitle,horiz=HorizontalLegend,border='black',bg='transparent',box.lty='solid',box.lwd=1,box.col='black',text.col='black',title.col='black',xpd=TRUE)



_________________
ImportDataframe.r



setwd(dir='C:/Users/Neonixx/Dropbox/R Pedagogy Project/')
list.files()
DataSourceFilename = 'X-lang_Regression.txt'
FirstLineIsColumnNames = TRUE
Separator = '\t'
Dataframe = RawDataframe = read.table( file=DataSourceFilename, header=FirstLineIsColumnNames, sep=Separator, quote='\'', dec='.', row.names=NULL, as.is=FALSE, na.strings='NA', colClasses=NA, nrows=0, skip=0, check.names=FALSE, fill=TRUE, strip.white=TRUE, blank.lines.skip=TRUE, comment.char='', allowEscapes=FALSE, flush=FALSE, stringsAsFactors=TRUE, fileEncoding='', encoding='unknown')
fix(Dataframe)
colnames(RawDataframe)
RowFilter = RawDataframe[,'LabelColumn1'] == 'Value'
Dataframe = RawDataframe[RowFilter,]



__________________________________________
LinearRegression_Multiple(TwoPredictors).r



﻿
colnames(Dataframe)
Name_PredictedVariable = 'NumberColumn1' 
Name_PredictorVariable1 = 'NumberColumn2' 
Name_PredictorVariable2 = 'NumberColumn3' 
PredictedVariable = Dataframe[,Name_PredictedVariable]
PredictorVariable1 = Dataframe[,Name_PredictorVariable1]
PredictorVariable2 = Dataframe[,Name_PredictorVariable2]
FittedModel = lm(formula=PredictedVariable~PredictorVariable1+PredictorVariable2, method='qr', singular.ok=FALSE, model=TRUE, x=TRUE, y=TRUE, qr=TRUE) 
ResultsSummary = summary.lm(object=FittedModel, correlation=TRUE)  
cat('\n\nMODEL USED\n~~~~~~~~~~\n\nA multiple linear regression was run, modeling the influence that\n   ', Name_PredictorVariable1, ' and ', Name_PredictorVariable2, ' have on ',Name_PredictedVariable, '.\n\n\nRESULTS\n~~~~~~~\n\nWhen ', Name_PredictorVariable1, ' and ', Name_PredictorVariable2, ' are both 0, ', Name_PredictedVariable, ' is approximately ', ResultsSummary$coefficients['(Intercept)','Estimate'], '\n   plus or minus a standard error of ', ResultsSummary$coefficients['(Intercept)','Std. Error'], '.\n   t=',ResultsSummary$coefficients['(Intercept)','t value'], ', p=', ResultsSummary$coefficients['(Intercept)','Pr(>|t|)'], '\n\nFor every increase of +1 in ', Name_PredictorVariable1, ', ', Name_PredictedVariable, ' changes by ', ResultsSummary$coefficients['PredictorVariable1','Estimate'], '\n   plus or minus a standard error of ', ResultsSummary$coefficients['PredictorVariable1','Std. Error'],'.\n   t=', ResultsSummary$coefficients['PredictorVariable1','t value'], ', p=', ResultsSummary$coefficients['PredictorVariable1','Pr(>|t|)'],'\n\nFor every increase of +1 in ', Name_PredictorVariable2, ', ', Name_PredictedVariable, ' changes by ', ResultsSummary$coefficients['PredictorVariable2','Estimate'], '\n   plus or minus a standard error of ', ResultsSummary$coefficients['PredictorVariable2','Std. Error'],'.\n   t=', ResultsSummary$coefficients['PredictorVariable2','t value'], ', p=', ResultsSummary$coefficients['PredictorVariable2','Pr(>|t|)'],'\n\nAs a whole, this model explains ',signif(100*ResultsSummary$adj.r.squared,2),'~',signif(100*ResultsSummary$r.squared,2),'% of the variance in ',Name_PredictedVariable,'.\n   F(',ResultsSummary$df[1],')=',as.numeric(ResultsSummary$fstatistic['value']),'\n   Multiple r-squared: ', ResultsSummary$r.squared, '\n   Adjusted r-squared: ', ResultsSummary$adj.r.squared, '\n\n',sep='')
print(ResultsSummary, digits=4, signif.stars=TRUE, symbolic.cor=FALSE)



_______________________________________
LinearRegression_Simple(OnePredictor).r



﻿
colnames(Dataframe)
PredictedVariableName = 'NumberColumn1' 
PredictorVariableName = 'NumberColumn2' 
PredictedVariable = Dataframe[,PredictedVariableName]
PredictorVariable = Dataframe[,PredictorVariableName]
FittedModel = lm(formula=PredictedVariable~PredictorVariable, method='qr', singular.ok=FALSE, model=TRUE, x=TRUE, y=TRUE, qr=TRUE) 
ResultsSummary = summary.lm(object=FittedModel, correlation=TRUE) 
cat('\n\nMODEL USED\n~~~~~~~~~~\n\nA simple linear regression was run, modeling the influence that\n   ', PredictorVariableName, ' has on ',PredictedVariableName, '.\n\n\nRESULTS\n~~~~~~~\n\nWhen ', PredictorVariableName, ' is 0, ', PredictedVariableName, ' is approximately ', ResultsSummary$coefficients['(Intercept)','Estimate'], '\n   plus or minus a standard error of ', ResultsSummary$coefficients['(Intercept)','Std. Error'], '.\n   t=',ResultsSummary$coefficients['(Intercept)','t value'], ', p=', ResultsSummary$coefficients['(Intercept)','Pr(>|t|)'], '\n\nFor every increase of +1 in ', PredictorVariableName, ', ', PredictedVariableName, ' changes by ', ResultsSummary$coefficients['PredictorVariable','Estimate'], '\n   plus or minus a standard error of ', ResultsSummary$coefficients['PredictorVariable','Std. Error'],'.\n   t=', ResultsSummary$coefficients['PredictorVariable','t value'], ', p=', ResultsSummary$coefficients['PredictorVariable','Pr(>|t|)'],'\n\nAs a whole, this model explains ',signif(100*ResultsSummary$adj.r.squared,2),'~',signif(100*ResultsSummary$r.squared,2),'% of the variance in ',PredictedVariableName,':\n   F(',ResultsSummary$df[1],')=',as.numeric(ResultsSummary$fstatistic['value']),'.\n   Multiple r-squared: ', ResultsSummary$r.squared, '\n   Adjusted r-squared: ', ResultsSummary$adj.r.squared, '\n\n',sep='')
print(ResultsSummary, digits=4, signif.stars=TRUE, symbolic.cor=FALSE)



___________________________________
LinearRegression_SpecifiedFormula.r



﻿
colnames(Dataframe)
Formula = NumberColumn1 ~ NumberColumn2 + NumberColumn3 + NumberColumn4
FittedModel = lm(formula=Formula, data=Dataframe, method='qr', singular.ok=FALSE, model=TRUE, x=TRUE, y=TRUE, qr=TRUE) 
ResultsSummary = summary.lm(object=FittedModel, correlation=TRUE)  
print(ResultsSummary, digits=4, signif.stars=TRUE, symbolic.cor=FALSE)



_________________________________
LogisticRegression_OnePredictor.r



colnames(Dataframe)
Name_BinaryPredictedVariable = 'BinaryResponseColumn'
Name_PredictorVariable = 'NumberColumn'
BinaryPredictedVariable = as.factor(Dataframe[,Name_BinaryPredictedVariable])
PredictorVariable = Dataframe[,Name_PredictorVariable]
FittedModel = glm(formula=BinaryPredictedVariable ~ PredictorVariable, family = binomial(link='logit'), data=Dataframe, start = NULL, model = TRUE, method = 'glm.fit', x = TRUE, y = TRUE, contrasts = NULL) 
ResultsSummary = summary.glm(object=FittedModel, dispersion=NULL, correlation=TRUE) 
cat('\n\nMODEL USED\n~~~~~~~~~~\n\nA simple logistic regression was run (using a ', FittedModel$family$family, ' error distribution\n   and ', FittedModel$family$link, ' link function), modeling the influence that ',Name_PredictorVariable,' has\n   on the proportion of '', levels(BinaryPredictedVariable)[2], '' (as opposed to '', levels(BinaryPredictedVariable)[1],'') in ', Name_BinaryPredictedVariable,'.\n\n\nRESULTS\n~~~~~~~\n\nWhen ', Name_PredictorVariable, ' is 0, the probability of getting '', levels(BinaryPredictedVariable)[2],'' is\n   approximately ', exp(ResultsSummary$coefficients['(Intercept)','Estimate']), ' (standard error ranging from ', max(0,exp(ResultsSummary$coefficients['(Intercept)','Estimate']-ResultsSummary$coefficients['(Intercept)','Std. Error'])), ' to ', min(exp(ResultsSummary$coefficients['(Intercept)','Estimate']+ResultsSummary$coefficients['(Intercept)','Std. Error']),1),').\n   z=',ResultsSummary$coefficients['(Intercept)','z value'], ', p=', ResultsSummary$coefficients['(Intercept)','Pr(>|z|)'], '\n\nFor every increase of +1 in ', Name_PredictorVariable, ', the probability of getting '', levels(BinaryPredictedVariable)[2],'' changes by\n   approximately ', 100*(exp(ResultsSummary$coefficients['PredictorVariable','Estimate'])-1), ' percent (standard error ranging from\n   ', 100*(exp(ResultsSummary$coefficients['PredictorVariable','Estimate']-ResultsSummary$coefficients['PredictorVariable','Std. Error'])-1), ' to ', 100*(exp(ResultsSummary$coefficients['PredictorVariable','Estimate']+ResultsSummary$coefficients['PredictorVariable','Std. Error'])-1),' percent).\n   z=',ResultsSummary$coefficients['PredictorVariable','z value'], ', p=', ResultsSummary$coefficients['PredictorVariable','Pr(>|z|)'], '\n\nAs a whole, this model explains ',signif(100*(1 - (FittedModel$deviance/FittedModel$null.deviance)),2),'% of the variance in ',Name_BinaryPredictedVariable,'.\n   Null deviance: ', FittedModel$null.deviance,'\n   Residual deviance: ', FittedModel$deviance,'\n   Akaike Information Criterion: ', FittedModel$aic,'\n\n\n',sep='')
print(ResultsSummary, digits=4, signif.stars=TRUE, symbolic.cor=FALSE)



_____________________________________
LogisticRegression_SpecifiedFormula.r



colnames(Dataframe)
Formula = BinaryValuesColumn ~ NumberColumn1 + NumberColumn2 + NumberColumn3
FittedModel = glm(formula=Formula, family = binomial(link='logit'), data=Dataframe, start = NULL, model = TRUE, method = 'glm.fit', x = TRUE, y = TRUE, contrasts = NULL) 
ResultsSummary = summary.glm(object=FittedModel, dispersion=NULL, correlation=TRUE) 
print(ResultsSummary, digits=4, signif.stars=TRUE, symbolic.cor=FALSE)



__________________________________
LogisticRegression_TwoPredictors.r



colnames(Dataframe)
Name_BinaryPredictedVariable = 'BinaryResponseColumn'
Name_PredictorVariable1 = 'NumberColumn1'
Name_PredictorVariable2 = 'NumberColumn2'
BinaryPredictedVariable = as.factor(Dataframe[,Name_BinaryPredictedVariable])
PredictorVariable1 = Dataframe[,Name_PredictorVariable1]
PredictorVariable2 = Dataframe[,Name_PredictorVariable2]
FittedModel = glm(formula=BinaryPredictedVariable ~ PredictorVariable1 + PredictorVariable2, family = binomial(link='logit'), data=Dataframe, start = NULL, model = TRUE, method = 'glm.fit', x = TRUE, y = TRUE, contrasts = NULL) 
ResultsSummary = summary.glm(object=FittedModel, dispersion=NULL, correlation=TRUE) 
cat('\n\nMODEL USED\n~~~~~~~~~~\n\nA simple logistic regression was run (using a ', FittedModel$family$family, ' error distribution\n   and ', FittedModel$family$link, ' link function), modeling the influence that ',Name_PredictorVariable1,' and ', Name_PredictorVariable2,'\n   have on the proportion of '', levels(BinaryPredictedVariable)[2], '' (as opposed to '', levels(BinaryPredictedVariable)[1],'') in ', Name_BinaryPredictedVariable,'.\n',sep='')
cat('\n\nRESULTS\n~~~~~~~\n\nWhen ', Name_PredictorVariable1, ' and ', Name_PredictorVariable2, ' are both 0, the probability of getting '', levels(BinaryPredictedVariable)[2],'' is\n   approximately ', exp(ResultsSummary$coefficients['(Intercept)','Estimate']), ' (standard error ranging from ', max(0,exp(ResultsSummary$coefficients['(Intercept)','Estimate']-ResultsSummary$coefficients['(Intercept)','Std. Error'])), ' to ', min(exp(ResultsSummary$coefficients['(Intercept)','Estimate']+ResultsSummary$coefficients['(Intercept)','Std. Error']),1),').\n   z=',ResultsSummary$coefficients['(Intercept)','z value'], ', p=', ResultsSummary$coefficients['(Intercept)','Pr(>|z|)'], '\n\nFor every increase of +1 in ', Name_PredictorVariable1, ', the probability of getting '', levels(BinaryPredictedVariable)[2],''\n   changes by approximately ', 100*(exp(ResultsSummary$coefficients['PredictorVariable1','Estimate'])-1), ' percent (standard error ranging from\n   ', 100*(exp(ResultsSummary$coefficients['PredictorVariable1','Estimate']-ResultsSummary$coefficients['PredictorVariable1','Std. Error'])-1), ' to ', 100*(exp(ResultsSummary$coefficients['PredictorVariable1','Estimate']+ResultsSummary$coefficients['PredictorVariable1','Std. Error'])-1),' percent).\n   z=',ResultsSummary$coefficients['PredictorVariable1','z value'], ', p=', ResultsSummary$coefficients['PredictorVariable1','Pr(>|z|)'], '\n\nFor every increase of +1 in ', Name_PredictorVariable2, ', the probability of getting '', levels(BinaryPredictedVariable)[2],''\n   changes by approximately ', 100*(exp(ResultsSummary$coefficients['PredictorVariable2','Estimate'])-1), ' percent (standard error ranging from\n   ', 100*(exp(ResultsSummary$coefficients['PredictorVariable2','Estimate']-ResultsSummary$coefficients['PredictorVariable2','Std. Error'])-1), ' to ', 100*(exp(ResultsSummary$coefficients['PredictorVariable2','Estimate']+ResultsSummary$coefficients['PredictorVariable2','Std. Error'])-1),' percent).\n   z=',ResultsSummary$coefficients['PredictorVariable2','z value'], ', p=', ResultsSummary$coefficients['PredictorVariable2','Pr(>|z|)'], '\n\nAs a whole, this model explains ',signif(100*(1 - (FittedModel$deviance/FittedModel$null.deviance)),2),'% of the variance in ',Name_BinaryPredictedVariable,'.\n   Null deviance: ', FittedModel$null.deviance,'\n   Residual deviance: ', FittedModel$deviance,'\n   Akaike Information Criterion: ', FittedModel$aic,'\n\n\n',sep='')
print(ResultsSummary, digits=4, signif.stars=TRUE, symbolic.cor=FALSE)



_____________________
MANOVA_OnePredictor.r



colnames(Dataframe)
Name_LabelColumn = 'LabelColumn1'
Names_NumberColumns = c('NumberColumn1','NumberColumn2')
NumberData = as.matrix( Dataframe[,c(Names_NumberColumns)] )
Conditions = Dataframe[,Name_LabelColumn]
FittedModel = aov(NumberData ~ Conditions, qr=TRUE, contrasts=NULL)
ResultsSummary = summary.manova(object=FittedModel, test='Pillai', intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)
cat('\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nUsing the grouping conditions in ', Name_LabelColumn, ', a one-way MANOVA was run on:\n   ',paste(Names_NumberColumns,collapse=', '),'\n   \n\nRESULTS\n~~~~~~~\nF(',ResultsSummary$stats['Conditions','Df'],',',ResultsSummary$stats['Residuals','Df'],') = ',ResultsSummary$stats['Conditions','approx F'],', p = ',ResultsSummary$stats['Conditions','Pr(>F)'],'\n\n\n',sep='')
show(ResultsSummary)
ResultsSummary = summary.manova(object=FittedModel, test='Wilks', intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)
ResultsSummary = summary.manova(object=FittedModel, test='Hotelling-Lawley', intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)
ResultsSummary = summary.manova(object=FittedModel, test='Roy',intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)



_________________________
MANOVA_SpecifiedFormula.r



colnames(Dataframe)
Names_NumberColumns = c('NumberColumn1','NumberColumn2')
y = as.matrix( Dataframe[,c(Names_NumberColumns)] )
Formula = y ~ LabelColumn1*LabelColumn2
FittedModel = aov(formula=Formula, data=Dataframe, qr=TRUE, contrasts=NULL)
summary.manova(object=FittedModel, test='Pillai', intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)
summary.manova(object=FittedModel, test='Wilks', intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)
summary.manova(object=FittedModel, test='Hotelling-Lawley', intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)
summary.manova(object=FittedModel, test='Roy',intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)



______________________
MANOVA_TwoPredictors.r



colnames(Dataframe)
Name_LabelColumn1 = 'LabelColumn1'
Name_LabelColumn2 = 'LabelColumn2'
Names_NumberColumns = c('NumberColumn1','NumberColumn2')
NumberData = as.matrix( Dataframe[,c(Names_NumberColumns)] )
Conditions1 = Dataframe[,Name_LabelColumn1]
Conditions2 = Dataframe[,Name_LabelColumn2]
FittedModel = aov(NumberData ~ Conditions1*Conditions2, qr=TRUE, contrasts=NULL)
ResultsSummary = summary.manova(object=FittedModel, test='Pillai', intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)
cat('\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nUsing the grouping conditions in ', Name_LabelColumn1, ' and ', Name_LabelColumn2, ',\n   a two-way MANOVA was run on: ',paste(Names_NumberColumns,collapse=' and '),'\n   \n\nRESULTS\n~~~~~~~\nMain effect of ', Name_LabelColumn1, ': F(',ResultsSummary$stats['Conditions1','Df'],',',ResultsSummary$stats['Residuals','Df'],') = ',ResultsSummary$stats['Conditions1','approx F'],', p = ',ResultsSummary$stats['Conditions1','Pr(>F)'],'\n\nMain effect of ', Name_LabelColumn2, ': F(',ResultsSummary$stats['Conditions2','Df'],',',ResultsSummary$stats['Residuals','Df'],') = ',ResultsSummary$stats['Conditions2','approx F'],', p = ',ResultsSummary$stats['Conditions2','Pr(>F)'],'\n\n',Name_LabelColumn1,'-',Name_LabelColumn2,' interaction: F(',ResultsSummary$stats['Conditions1:Conditions2','Df'],',',ResultsSummary$stats['Residuals','Df'],') = ',ResultsSummary$stats['Conditions1:Conditions2','approx F'],', p = ',ResultsSummary$stats['Conditions1:Conditions2','Pr(>F)'],'\n\n\n',sep='')
show(ResultsSummary)
ResultsSummary = summary.manova(object=FittedModel, test='Wilks', intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)
ResultsSummary = summary.manova(object=FittedModel, test='Hotelling-Lawley', intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)
ResultsSummary = summary.manova(object=FittedModel, test='Roy',intercept=FALSE, tol = 1e-7, keep.zero.df=TRUE)



__________________
t-test_OneSample.r



colnames(Dataframe)
NumberColumnName = 'NumberColumn1'
NumberData = Dataframe[,NumberColumnName]
Mean_NullHypothesis = 0
Directionality_AlternativeHypothesis = 'two.sided'
PercentageForConfidenceInterval = 0.95
Results = t.test( x=NumberData, alternative=Directionality_AlternativeHypothesis, mu=Mean_NullHypothesis, conf.level=PercentageForConfidenceInterval)
if(as.character(Results$alternative)=='two.sided'){AlternativeText=paste('The true mean is not equal to ', as.numeric(Results$null.value),'.',sep='')}
if(as.character(Results$alternative)=='greater'){AlternativeText=paste('The true mean is greater than ', as.numeric(Results$null.value),'.',sep='')}
if(as.character(Results$alternative)=='less'){AlternativeText=paste('The true mean is less than ', as.numeric(Results$null.value),'.',sep='')}
cat('\n\nDESCRIPTIVE STATISTICS\n~~~~~~~~~~~~~~~~~~~~~~\nThe actual calculated mean of ' ,NumberColumnName,' is ', as.numeric(Results$estimate),'.\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nA ', Results$method, ' was performed on ', NumberColumnName,'.\n - Null hypothesis: The true mean is ', as.numeric(Results$null.value),'.\n - Alternative hypothesis: ',AlternativeText,'\n\nRESULTS\n~~~~~~~\nThe ',100*PercentageForConfidenceInterval,'% confidence interval for the mean of ',NumberColumnName,' ranges\n   from ', as.numeric(Results$conf.int[1]), ' to ', as.numeric(Results$conf.int[2]),'.\nt(', as.numeric(Results$parameter), ')=', as.numeric(Results$statistic), ', p=',as.numeric(Results$p.value),'\n\n\n',sep='')
show(Results)



_______________________________________________________
t-test_TwoSample_NumberColumnAndLabelColumn(Unpaired).r



colnames(Dataframe)
NumberColumnName  = 'NumberColumn1'
LabelColumnName = 'LabelColumn'
NumberData = Dataframe[,NumberColumnName]
IdentifierLabels = Dataframe[,LabelColumnName]
unique(IdentifierLabels)
LabelA = 'Value1'
LabelB = 'Value2'
Subset = IdentifierLabels == LabelA |  IdentifierLabels == LabelB
DifferenceInAverages_NullHypothesis = 0
Directionality_AlternativeHypothesis = 'two.sided'
var(NumberData[IdentifierLabels == LabelA])
var(NumberData[IdentifierLabels == LabelB])
VariancesEqual = FALSE
PercentageForConfidenceInterval = 0.95
Results = t.test( formula=NumberData~IdentifierLabels, subset=Subset, na.action = na.fail,alternative=Directionality_AlternativeHypothesis, mu=DifferenceInAverages_NullHypothesis, paired=FALSE, var.equal=VariancesEqual, conf.level=PercentageForConfidenceInterval)
{if(VariancesEqual==TRUE){VarianceAssumption='The analysis assumed that the two distributions each had the same variance.\n'}else{VarianceAssumption='The analysis assumed the two distributions have different variances.\n'}
if(as.character(Results$alternative)=='two.sided'){AlternativeText=paste('The true difference in means is not equal to ', as.numeric(Results$null.value),'.',sep='')}
if(as.character(Results$alternative)=='greater'){AlternativeText=paste('The true difference in means is greater than ', as.numeric(Results$null.value),'.',sep='')}
if(as.character(Results$alternative)=='less'){AlternativeText=paste('The true difference in means is less than ', as.numeric(Results$null.value),'.',sep='')}
cat('\n\nDESCRIPTIVE STATISTICS\n~~~~~~~~~~~~~~~~~~~~~~\nThe mean of ' ,LabelA,' is ', as.numeric(Results$estimate)[1],'.\nThe mean of ',LabelB,' is ',as.numeric(Results$estimate)[2],'.\nHence the actual calculated difference in means\n   (',LabelA,' minus ', LabelB,') is ', as.numeric(Results$estimate[1] - Results$estimate[2]),'.\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nAn Unpaired ', Results$method, ' was performed on ', LabelA,' and ', LabelB,'.\n', ' - Null hypothesis: The true difference in means is ', as.numeric(Results$null.value),'.\n - Alternative hypothesis: ',AlternativeText,'\n',VarianceAssumption,'\nRESULTS\n~~~~~~~\nThe ',100*PercentageForConfidenceInterval,'% confidence interval for the difference in means ranges\n   from ', as.numeric(Results$conf.int[1]), ' to ', as.numeric(Results$conf.int[2]),'.\nt(', as.numeric(Results$parameter), ')=', as.numeric(Results$statistic), ', p=',as.numeric(Results$p.value),'\n\n\n',sep='')}
show(Results)



__________________________________________
t-test_TwoSample_TwoNumberColumns_Paired.r



colnames(Dataframe)
ColumnNameA = 'NumberColumn1'
ColumnNameB = 'NumberColumn2'
NumberDataA = Dataframe[,ColumnNameA]
NumberDataB = Dataframe[,ColumnNameB]
DifferenceInAverages_NullHypothesis = 0
Directionality_AlternativeHypothesis = 'less'
PercentageForConfidenceInterval = 0.95
Results = t.test( x=NumberDataA, y=NumberDataB, alternative=Directionality_AlternativeHypothesis, mu=DifferenceInAverages_NullHypothesis, paired=TRUE, var.equal=VariancesEqual, conf.level=PercentageForConfidenceInterval)
{if(as.character(Results$alternative)=='two.sided'){AlternativeText=paste('The true average difference is not equal to ', as.numeric(Results$null.value),'.',sep='')}
if(as.character(Results$alternative)=='greater'){AlternativeText=paste('The true average difference is greater than ', as.numeric(Results$null.value),'.',sep='')}
if(as.character(Results$alternative)=='less'){AlternativeText=paste('The true average difference is less than ', as.numeric(Results$null.value),'.',sep='')}
cat('\n\nDESCRIPTIVE STATISTICS\n~~~~~~~~~~~~~~~~~~~~~~\nAcross all the paired data points, the average difference\n   (',ColumnNameA,' minus ', ColumnNameB,') is ', as.numeric(Results$estimate),'.\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nA ', Results$method, ' was performed on ', ColumnNameA,' and ', ColumnNameB,'.\n', ' - Null hypothesis: The true average difference is ', as.numeric(Results$null.value),'.\n - Alternative hypothesis: ',AlternativeText,'\n\nRESULTS\n~~~~~~~\nThe ',100*PercentageForConfidenceInterval,'% confidence interval for the average difference ranges\n   from ', as.numeric(Results$conf.int[1]), ' to ', as.numeric(Results$conf.int[2]),'.\nt(', as.numeric(Results$parameter), ')=', as.numeric(Results$statistic), ', p=',as.numeric(Results$p.value),'\n\n\n',sep='')}
show(Results)



____________________________________________
t-test_TwoSample_TwoNumberColumns_Unpaired.r



colnames(Dataframe)
ColumnNameA = 'NumberColumn1'
ColumnNameB = 'NumberColumn2'
NumberDataA = Dataframe[,ColumnNameA]
NumberDataB = Dataframe[,ColumnNameB]
DifferenceInAverages_NullHypothesis = 0
Directionality_AlternativeHypothesis = 'two.sided'
var(NumberDataA)
var(NumberDataB)
VariancesEqual = TRUE
PercentageForConfidenceInterval = 0.95
Results = t.test( x=NumberDataA, y=NumberDataB, alternative=Directionality_AlternativeHypothesis, mu=DifferenceInAverages_NullHypothesis, paired=FALSE, var.equal=VariancesEqual, conf.level=PercentageForConfidenceInterval)
if(VariancesEqual==TRUE){VarianceAssumption='The analysis assumed that the two distributions each had the same variance.\n'}else{VarianceAssumption='The analysis assumed the two distributions have different variances.\n'
Results$method='Two Sample t-test'}
if(as.character(Results$alternative)=='two.sided'){AlternativeText=paste('The true difference in means is not equal to ', as.numeric(Results$null.value),'.',sep='')}
if(as.character(Results$alternative)=='greater'){AlternativeText=paste('The true difference in means is greater than ', as.numeric(Results$null.value),'.',sep='')}
if(as.character(Results$alternative)=='less'){AlternativeText=paste('The true difference in means is less than ', as.numeric(Results$null.value),'.',sep='')}
cat('\n\nDESCRIPTIVE STATISTICS\n~~~~~~~~~~~~~~~~~~~~~~\nThe mean of ' ,ColumnNameA,' is ', as.numeric(Results$estimate)[1],'.\nThe mean of ',ColumnNameB,' is ',as.numeric(Results$estimate)[2],'.\nHence the actual calculated difference in means\n   (',ColumnNameA,' minus ', ColumnNameB,') is ', as.numeric(Results$estimate[1] - Results$estimate[2]),'.\n\nTEST THAT WAS RUN\n~~~~~~~~~~~~~~~~~\nAn Unpaired ',Results$method, ' was performed on ', ColumnNameA,' and ', ColumnNameB,'.\n', ' - Null hypothesis: The true difference in means is ', as.numeric(Results$null.value),'.\n - Alternative hypothesis: ',AlternativeText,'\n',VarianceAssumption,'\nRESULTS\n~~~~~~~\nThe ',100*PercentageForConfidenceInterval,'% confidence interval for the difference in means ranges\n   from ', as.numeric(Results$conf.int[1]), ' to ', as.numeric(Results$conf.int[2]),'.\nt(', as.numeric(Results$parameter), ')=', as.numeric(Results$statistic), ', p=',as.numeric(Results$p.value),'\n\n\n',sep='')
show(Results)
