﻿# Multiple linear regression (i.e. with two predictor)
# by Aaron Albin
# Script began: 3/12/2012

###########################
# WHEN TO USE THIS SCRIPT #
########################### 

# Use this script if you can answer 'yes' to all of the following questions:

# A) Inside your dataframe, you have three sets of numeric data stored as three separate columns.
# B) You are interested in how two of the sets of numbers, when taken together, can predict the other one. More specifically, you want to know, "For each increase in data X1 and X2 (the "predictor/dependent" variables) by a unit of 1, how much does my data Y (the "predicted/independent/response variable") change?"

# Several examples:
# - Do high school SAT scores and college entrance exam scores predict college GPA?
# - Do extent of stress and amount of sleep predict how well you will do on an exam?
# - Do a baby's birth weight and birth height predict how many colds it will have in infancy?
# Modified from: http://www.wadsworth.com/psychology_d/special_features/ext/workshops/correlation.html
# Note: Original source is about correlation, but the examples are also applicable here.

###############
# SELECT DATA #
###############

# Run this to have R tell you the names for each of the columns that it ended up with:
#=====[1]=====
colnames(Dataframe)
#=============

# Now, pick out which three of these columns have your number data.
# To do so, first determine which of these is the predicted/dependent variable and which other two are the predictor variables.
# Type the names of those columns between the double-quotes below.
#=====[2]=====
Name_PredictedVariable = "NumberColumn1" # AKA dependent/response variable 
Name_PredictorVariable1 = "NumberColumn2" # AKA independent variable
Name_PredictorVariable2 = "NumberColumn3" # AKA independent variable
#Name_PredictedVariable="VOT1";Name_PredictorVariable1="J_ANS_B";Name_PredictorVariable2="K_ANS_B"
#=============

# Now run this to extract out the specific columns data you selected
#=====[3]=====
PredictedVariable = Dataframe[,Name_PredictedVariable]
PredictorVariable1 = Dataframe[,Name_PredictorVariable1]
PredictorVariable2 = Dataframe[,Name_PredictorVariable2]
#=============

###########################
# SET UP AND RUN ANALYSIS #
###########################

# Run these two lines of code to conduct the analysis:
#=====[4]=====
FittedModel = lm(formula=PredictedVariable~PredictorVariable1+PredictorVariable2, method="qr", singular.ok=FALSE, model=TRUE, x=TRUE, y=TRUE, qr=TRUE) # Fits a linear model to the data
ResultsSummary = summary.lm(object=FittedModel, correlation=TRUE)  # Computes various summary statistics of FittedModel, including the correlation between the intercept and the two predictor variables
#=============

#######################
# INSPECT THE RESULTS #
#######################

# Run the following code for a reformatted, easy-to-read representation of the results:
#=====[5]=====
cat("\n\nMODEL USED\n~~~~~~~~~~\n\nA multiple linear regression was run, modeling the influence that\n   ", Name_PredictorVariable1, " and ", Name_PredictorVariable2, " have on ",Name_PredictedVariable, ".\n\n\nRESULTS\n~~~~~~~\n\nWhen ", Name_PredictorVariable1, " and ", Name_PredictorVariable2, " are both 0, ", Name_PredictedVariable, " is approximately ", ResultsSummary$coefficients["(Intercept)","Estimate"], "\n   plus or minus a standard error of ", ResultsSummary$coefficients["(Intercept)","Std. Error"], ".\n   t=",ResultsSummary$coefficients["(Intercept)","t value"], ", p=", ResultsSummary$coefficients["(Intercept)","Pr(>|t|)"], "\n\nFor every increase of +1 in ", Name_PredictorVariable1, ", ", Name_PredictedVariable, " changes by ", ResultsSummary$coefficients["PredictorVariable1","Estimate"], "\n   plus or minus a standard error of ", ResultsSummary$coefficients["PredictorVariable1","Std. Error"],".\n   t=", ResultsSummary$coefficients["PredictorVariable1","t value"], ", p=", ResultsSummary$coefficients["PredictorVariable1","Pr(>|t|)"],"\n\nFor every increase of +1 in ", Name_PredictorVariable2, ", ", Name_PredictedVariable, " changes by ", ResultsSummary$coefficients["PredictorVariable2","Estimate"], "\n   plus or minus a standard error of ", ResultsSummary$coefficients["PredictorVariable2","Std. Error"],".\n   t=", ResultsSummary$coefficients["PredictorVariable2","t value"], ", p=", ResultsSummary$coefficients["PredictorVariable2","Pr(>|t|)"],"\n\nAs a whole, this model explains ",signif(100*ResultsSummary$adj.r.squared,2),"~",signif(100*ResultsSummary$r.squared,2),"% of the variance in ",Name_PredictedVariable,".\n   F(",ResultsSummary$df[1],")=",as.numeric(ResultsSummary$fstatistic["value"]),"\n   Multiple r-squared: ", ResultsSummary$r.squared, "\n   Adjusted r-squared: ", ResultsSummary$adj.r.squared, "\n\n",sep="")
#=============

# Here is R's default display of the results:
#=====[6]=====
print(ResultsSummary, digits=4, signif.stars=TRUE, symbolic.cor=FALSE)
#=============
