﻿# Simple linear regression (i.e. with one predictor)
# by Aaron Albin
# Script began: 2/1/2012

###########################
# WHEN TO USE THIS SCRIPT #
########################### 

# Use this script if you can answer 'yes' to all of the following questions:

# A) Inside your dataframe, you have two sets of numeric data stored as two separate columns.
# B) You are interested in the predictive relationship between the two. More specifically, you want to know, "For each increase in data X (the "predictor/dependent" variable) by a unit of 1, how much does my data Y (the "predicted/independent/response variable") change?"

# Several examples:
# - Does high school SAT scores predict college GPA?
# - Does extent of stress predict how well you will do on an exam?
# - Does a baby's birth weight predict how many colds it will have in infancy?
# Source: http://www.wadsworth.com/psychology_d/special_features/ext/workshops/correlation.html
# Note: Original source is about correlation, but the examples are also applicable here.

###############
# SELECT DATA #
###############

# Run this to have R tell you the names for each of the columns that it ended up with:
#=====[1]=====
colnames(Dataframe)
#=============

# Now, pick out which of these columns has your number data.
# To do so, first determine which of these is the predicted/dependent variable and which is the predictor variable.
# Type the names of those columns between the double-quotes below.
#=====[2]=====
PredictedVariableName = "NumberColumn1" # AKA dependent/response variable 
PredictorVariableName = "NumberColumn2" # AKA independent variable
#PredictedVariableName="VOT1";PredictorVariableName="ANS_B"
#=============

# Now run this to extract out the specific columns data you selected
#=====[3]=====
PredictedVariable = Dataframe[,PredictedVariableName]
PredictorVariable = Dataframe[,PredictorVariableName]
#=============

###########################
# SET UP AND RUN ANALYSIS #
###########################

# Run these two lines of code to conduct the analysis:
#=====[4]=====
FittedModel = lm(formula=PredictedVariable~PredictorVariable, method="qr", singular.ok=FALSE, model=TRUE, x=TRUE, y=TRUE, qr=TRUE) # Fits a linear model to the data
ResultsSummary = summary.lm(object=FittedModel, correlation=TRUE) # Computes various summary statistics of FittedModel, including the correlation between the intercept and the predictor variable
#=============


#######################
# INSPECT THE RESULTS #
#######################

# Run the following code for a reformatted, easy-to-read representation of the results:
#=====[5]=====
cat("\n\nMODEL USED\n~~~~~~~~~~\n\nA simple linear regression was run, modeling the influence that\n   ", PredictorVariableName, " has on ",PredictedVariableName, ".\n\n\nRESULTS\n~~~~~~~\n\nWhen ", PredictorVariableName, " is 0, ", PredictedVariableName, " is approximately ", ResultsSummary$coefficients["(Intercept)","Estimate"], "\n   plus or minus a standard error of ", ResultsSummary$coefficients["(Intercept)","Std. Error"], ".\n   t=",ResultsSummary$coefficients["(Intercept)","t value"], ", p=", ResultsSummary$coefficients["(Intercept)","Pr(>|t|)"], "\n\nFor every increase of +1 in ", PredictorVariableName, ", ", PredictedVariableName, " changes by ", ResultsSummary$coefficients["PredictorVariable","Estimate"], "\n   plus or minus a standard error of ", ResultsSummary$coefficients["PredictorVariable","Std. Error"],".\n   t=", ResultsSummary$coefficients["PredictorVariable","t value"], ", p=", ResultsSummary$coefficients["PredictorVariable","Pr(>|t|)"],"\n\nAs a whole, this model explains ",signif(100*ResultsSummary$adj.r.squared,2),"~",signif(100*ResultsSummary$r.squared,2),"% of the variance in ",PredictedVariableName,":\n   F(",ResultsSummary$df[1],")=",as.numeric(ResultsSummary$fstatistic["value"]),".\n   Multiple r-squared: ", ResultsSummary$r.squared, "\n   Adjusted r-squared: ", ResultsSummary$adj.r.squared, "\n\n",sep="")
#=============

# Here is R's default display of the results:
#=====[6]=====
print(ResultsSummary, digits=4, signif.stars=TRUE, symbolic.cor=FALSE)
#=============
