﻿# Multiple linear regression (via a specified formula)
# by Aaron Albin
# Script began: 2/1/2012

###########################
# WHEN TO USE THIS SCRIPT #
########################### 

# Use this script if you can answer 'yes' to all of the following questions:

# A) Inside your dataframe, you have multiple sets of numeric data stored in separate columns.
# B) You are interested in how several of the sets of numbers, when taken together, can predict one of the others. More specifically, you want to know, "For each increase in data X1, X2, etc. (the "predictor/dependent" variables) by a unit of 1, how much does my data Y (the "predicted/independent/response variable") change?"

# Several examples:
# - Do high school SAT scores, college entrance exam scores, and high school GPA predict college GPA?
# - Do extent of stress, amount of sleep, and number of hours studied predict how well you will do on an exam?
# - Do a baby's birth weight, birth height, and number of months developed before birth predict how many colds it will have in infancy?
# Modified from: http://www.wadsworth.com/psychology_d/special_features/ext/workshops/correlation.html
# Note: Original source is about correlation, but the examples are also applicable here.

###############
# SELECT DATA #
###############

# Run this to have R tell you the names for each of the columns that it ended up with:
#=====[1]=====
colnames(Dataframe)
#=============

# In this part of the script, you'll be writing a formula expressing how you think your variables are related to one another.
# The specific labels you'll use will come from the column names you obtained from Step 1.
# Do NOT use double-quotes around each of the column names in this particular context.

# Here are three examples:

# [EXAMPLE 1] Formula = y ~ a
# Simple linear regression

# [EXAMPLE 2] Formula = y ~ a + b
# Multiple linear regression with two predictor variables

# [EXAMPLE 3] Formula = y ~ a + b + c
# Multiple linear regression with three predictor variables

# To the left of the tilde ('~') sign, write the column name for the predicted ('response'/'dependent') variable.
# Then, to the right of the tilde sign, write the column name for each of the the predictor ('independent') variables you want to include in the model, each of which must be separated by plus signs ('+').

# All formulas have an implied intercept term unless it is removed by adding either '-1' or '+0' to the function. Thus, for example, rather than 'y ~ a + b', you would write 'y ~ a + b - 1' or 'y ~ a + b + 0'

# See the 'ANOVA- Specified formula' or 'MANOVA- Specified formula' scripts for how to specify interactions in a formula, something that is less commonly done in regression modeling.

# To make a nonlinear regression (e.g. quadratic, polynomial, etc.), surround the desired predictors with 'poly(..., 2)[,2]', 'poly(..., 3)[,3]', etc. - however many degrees you want. (Make sure the number inside the parentheses and the number in the square brackets match up.)
# Example: Formula = NumberColumnA ~ poly(NumberColumnB, 2)[,2] # For a second-order (i.e. quadratic) line

# Here, please specify your formula:
#=====[2]=====
Formula = NumberColumn1 ~ NumberColumn2 + NumberColumn3 + NumberColumn4
# Formula = K_CONF ~ voiceless + F2
#=============

###########################
# SET UP AND RUN ANALYSIS #
###########################

# Run these two lines of code to conduct the analysis:
#=====[3]=====
FittedModel = lm(formula=Formula, data=Dataframe, method="qr", singular.ok=FALSE, model=TRUE, x=TRUE, y=TRUE, qr=TRUE) # Fits a linear model to the data
ResultsSummary = summary.lm(object=FittedModel, correlation=TRUE)  # Computes various summary statistics of FittedModel, including the correlation between all the terms in the model (i.e. the intercept, if there is one, and the various predictor variables and their interactions)
#=============

#######################
# INSPECT THE RESULTS #
#######################

# Here is R's default display of the results:
#=====[4]=====
print(ResultsSummary, digits=4, signif.stars=TRUE, symbolic.cor=FALSE)
#=============
