# Multiple logistic regression (via a specified formula)
# by Aaron Albin
# Script began: 2/1/2012

###########################
# WHEN TO USE THIS SCRIPT #
########################### 

# Use this script if you can answer 'yes' to all of the following questions:

# A) The predicted variable in your dataset is binary (AKA 'dichotomous'), i.e. Yes/No, True/False, Accept/Reject, etc., and this is stored in one column of your dataframe.
# B) You have multiple predictor variables in your dataset, each of which is continuous-numeric (i.e. numbers with decimal places), and these are stored in various separate columns.
# C) You are interested determining whether changes in your predictor variables (more or less on the continuous scales) have a systematic effect on your binary predicted variable (in terms of raising or lowering the proportion of 'Yes'es as opposed to 'No's, etc.).

# Examples:
# * Predicting whether a hospital patient does or does not have some sort of health-related problem based on their blood pressure, level of anxiety, and heart rate
# * Predicting whether a person is male or female based on their height, weight, and waist size

###############
# SELECT DATA #
###############

# Run this to have R tell you the names for each of the columns that it ended up with:
#=====[1]=====
colnames(Dataframe)
#=============

# In this part of the script, you'll be writing a formula expressing how you think your variables are related to one another.
# The specific labels you'll use will come from the column names you obtained from Step 1.
# Do NOT use double-quotes around each of the column names in this particular context.

# Here are three examples:

# [EXAMPLE 1] Formula = y ~ a
# Simple linear regression

# [EXAMPLE 2] Formula = y ~ a + b
# Multiple linear regression with two predictor variables

# [EXAMPLE 3] Formula = y ~ a + b + c
# Multiple linear regression with three predictor variables

# To the left of the tilde ('~') sign, write the column name for the predicted ('response'/'dependent') variable.
# Then, to the right of the tilde sign, write the column name for each of the the predictor ('independent') variables you want to include in the model, each of which must be separated by plus signs ('+').

# All formulas have an implied intercept term unless it is removed by adding either '-1' or '+0' to the function. Thus, for example, rather than 'y ~ a + b', you would write 'y ~ a + b - 1' or 'y ~ a + b + 0'

# See the 'ANOVA- Specified formula' or 'MANOVA- Specified formula' scripts for how to specify interactions in a formula, something that is less commonly done in (logistic) regression modeling.

# Here, please specify your formula:
#=====[2]=====
Formula = BinaryValuesColumn ~ NumberColumn1 + NumberColumn2 + NumberColumn3
# Formula = CONSONAT ~ F1 + F2 + F3
#=============

###########################
# SET UP AND RUN ANALYSIS #
###########################

# Run these two lines of code to conduct the analysis:
#=====[3]=====
FittedModel = glm(formula=Formula, family = binomial(link="logit"), data=Dataframe, start = NULL, model = TRUE, method = "glm.fit", x = TRUE, y = TRUE, contrasts = NULL) # Fits a linear model to the data using iteratively reweighted least squares
ResultsSummary = summary.glm(object=FittedModel, dispersion=NULL, correlation=TRUE) # Obtains a summary of the results of the the Generalized Linear Model fit just conducted
#=============

#######################
# INSPECT THE RESULTS #
#######################

# Here is R's default display of the results:
#=====[4]=====
print(ResultsSummary, digits=4, signif.stars=TRUE, symbolic.cor=FALSE)
#=============

# For advanced users:
# The glm() function used here is incredibly flexible and can handle a wide variety of error distributions and link functions:
# * Error distributions: "gaussian", "inverse.gaussian", "Gamma", "binomial", "quasibinomial", "poisson", "quasipoisson", and "quasi".
# * Link functions: identity, inverse, normal, logarithmic, complementary logarithmic-logarithmic, square root, 1/mean^2, Cauchy, power, and logistic.
# Type '?family' (without the single-quotes) at the console and hit ENTER for further information.
